"use server";

import * as auth from "@/auth";
import { USER_API } from "@/services/api-end-point/user";
import clientAxios from "@/services/config";
import axios from "axios";
import { redirect } from "next/navigation";
import { z } from "zod";

const createUserSchema = z.object({
  name: z.string().min(3),
  email: z.string().email(),
  phone: z.string().min(11).max(14),
  password: z.string().min(8),
  // .regex(
  //   /^(?=.*[0-9])(?=.*[a-zA-Z])([a-zA-Z0-9]+)$/,
  //   "password must contains at least one character and one number"
  // ),
});

interface CreateUserFormState {
  errors: {
    name?: string[];
    email?: string[];
    phone?: string[];
    password?: string[];
    _form?: string[];
  };
}

export async function signIn() {
  return auth.signIn("github");
}

export async function credentialsSignIn(
  formState: CreateUserFormState,
  formData: FormData,
  additionalData?: { phone: string }
): Promise<CreateUserFormState> {
  const email = formData?.get("email") as string;
  const password = formData?.get("password") as string;
  console.log(email, password)
  const phone = additionalData?.phone || formData?.get("phone") as string;
  const requestBody = {
    email,
    password,
    phone
  };
  const authResponse = await fetch("https://backend.seniorbhaiya.com/users/login", {
    method: "POST",
    headers: {
      "Content-Type": "application/json",
    },
    body: JSON.stringify(requestBody),
  });
  if (!authResponse.ok) {
    return {
      errors: {
        _form: ["Invalid Credentials"],
      },
    };
  }
  const user = await authResponse.json();
  const data = {
    accessToken: user.accessToken,
    name: user.user.name,
    email: user.user.email,
    id: user.user._id,
    image: user.user.image,
  };

  return auth.signIn("credentials", data);
}


export async function credentialsSignUp(
  formState: CreateUserFormState,
  formData: FormData
): Promise<CreateUserFormState> {
  const role = formData.get("role") as string;
  const result = createUserSchema.safeParse({
    name: formData.get("name"),
    email: formData.get("email"),
    phone: formData.get("phone"),
    password: formData.get("password"),
  });

  if (!result.success) {
    return {
      errors: result.error.flatten().fieldErrors,
    };
  }

  // console.log(JSON.stringify({
  //   name: result.data.name,
  //   username: result.data.email,
  //   email: result.data.email,
  //   phone: result.data.phone,
  //   password: result.data.password,
  //   role,
  // }, null, 2))

  try {
    let a = await axios.post(`https://backend.seniorbhaiya.com/users/create`, {
      name: result.data.name,
      username: result.data.email,
      email: result.data.email,
      phone: result.data.phone.startsWith("+88")
        ? result.data.phone
        : "+88" + result.data.phone,
      password: result.data.password,
      role,
    });
    
  } catch (err: any) {
    
    if (err) {
      return {
        errors: {
          _form: [err?.response?.data?.message],
        },
      };
    } else {
      return {
        errors: {
          _form: ["Something went wrong"],
        },
      };
    }
  }
  redirect("/login");
  // return auth.signIn("credentials", { name, email, phone, password, role });
}
