"use client";

import { useState, useEffect } from "react";
import { fetchAssignment } from "@/actions/video";
import { AssignmentModal } from "@/models/assignment";

import { useSession } from "next-auth/react";
import { useRouter } from "next/navigation";
import clientAxios from "@/services/config";
import { QUESTION_MARKS_API } from "@/services/api-end-point/questionMarks";
import axios from "axios";
import moment from "moment";

interface CourseAssignmentPageProps {
  params: {
    courseSlug: string;
    slug: string;
  };
}

const AssignmentPage = ({ params }: CourseAssignmentPageProps) => {
  const [errors, setErrors] = useState<any>();
  const session = useSession();
  const [assignment, setAssignment] = useState<AssignmentModal>({});

  const router = useRouter();
  useEffect(() => {
    fetchAssignment(params.courseSlug).then((res) => {
      setAssignment(res[0]);
    });
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  const handleDownload = () => {
    const { assignmentFile } = assignment;
    const anchor = document.createElement("a");
    if (assignmentFile) anchor.href = assignmentFile;
    anchor.setAttribute("download", "assignmentFile.pdf");
    document.body.appendChild(anchor);
    anchor.click();
    document.body.removeChild(anchor);
  };

  const handleFileChange = (event: any) => {
    const file = event.target.files[0];
    if (file) {
      const reader = new FileReader();
      reader.onloadend = () => {
        setAssignment({
          ...assignment,
          assignmentFile: (reader as any).result?.split(",")[1],
        });
      };
      reader.readAsDataURL(file);
    }
  };

  const handleSubmit = async () => {
    const payload = {
      totalQuestion: 0,
      mark: 10,
      totalMark: assignment?.totalMarks,
      negativeMark: 0,
      totalWrong: 0,
      totalCorrect: 0,
      questionType: "ASSIGNMENT",
      studentId: session?.data?.user ? session.data?.user?.id : "",
      studentName: session?.data?.user ? session.data?.user?.name : "",
      lessonId: assignment.lessonId,
      lessonName: assignment.lessonName,
      courseId: params.slug,
      isPassed: true,
      assignmentId: assignment._id,
      assignmentFile: assignment?.assignmentFile || "",
    };
    try {
      await clientAxios.post(QUESTION_MARKS_API.create_assignment, payload);
      router.push(`/${params.slug}/course/${params.courseSlug}`);
    } catch (error) {
      if (error instanceof Error) {
        setErrors(error.message);
      } else {
        setErrors("Something went wrong");
      }
    }
  };

  return (
    <div className="container mx-auto px-4 sm:px-8 mt-4">
      <div className="mb-8">
        <h1 className="text-2xl font-bold text-gray-700 dark:text-white">
          {`Assignment for ${assignment.lessonName}`}
        </h1>
        <p className="text-sm text-gray-700 dark:text-white">
          Assignment contains {assignment.totalMarks} Mark
        </p>
      </div>
      <div className="flex items-center sm:gap-3 gap-2">
        <span className="text-black dark:text-white sm:text-base font-bold text-xl">
          Ending In:
        </span>
        {moment(assignment.deadLine).format("DD-MM-YYYY")}
      </div>
      {assignment?.assignment && (
        <div dangerouslySetInnerHTML={{ __html: assignment?.assignment }} />
      )}
      {/* <iframe
        className="w-full h-96"
        src={assignment?.assignmentFile}
        title="assignment"
      /> */}

      {/* <p className="text-black dark:text-white lg:text-base sm:text-base font-bold text-xl  sm:py-2 max-sm:pb-1 max-md:hidden">
        Download File
      </p> */}
      {/* <button
        className="download-button transform active:scale-95 bg-blue-500 hover:bg-blue-400 text-white px-3 py-3 rounded-lg font-bold tracking-widest w-56"
        onClick={handleDownload}
      >
        <div className="flex justify-center items-center relative">
          <div className="svg-container">
            <svg
              className="download-icon"
              width="18"
              height="22"
              viewBox="0 0 18 22"
              fill="none"
              xmlns="http://www.w3.org/2000/svg"
            >
              <path
                className="download-arrow"
                d="M13 9L9 13M9 13L5 9M9 13V1"
                stroke="#F2F2F2"
                stroke-width="2"
                stroke-linecap="round"
                stroke-linejoin="round"
              />
              <path
                d="M1 17V18C1 18.7956 1.31607 19.5587 1.87868 20.1213C2.44129 20.6839 3.20435 21 4 21H14C14.7956 21 15.5587 20.6839 16.1213 20.1213C16.6839 19.5587 17 18.7956 17 18V17"
                stroke="#F2F2F2"
                stroke-width="2"
                stroke-linecap="round"
                stroke-linejoin="round"
              />
            </svg>
            <div className="download-loader text-white hidden"></div>
            <svg
              className="check-svg hidden"
              width="20"
              height="20"
              viewBox="0 0 20 20"
              fill="none"
              xmlns="http://www.w3.org/2000/svg"
            >
              <path
                fill-rule="evenodd"
                clip-rule="evenodd"
                d="M10 20C15.5228 20 20 15.5228 20 10C20 4.47715 15.5228 0 10 0C4.47715 0 0 4.47715 0 10C0 15.5228 4.47715 20 10 20ZM15.1071 7.9071C15.4976 7.51658 15.4976 6.88341 15.1071 6.49289C14.7165 6.10237 14.0834 6.10237 13.6929 6.49289L8.68568 11.5001L7.10707 9.92146C6.71655 9.53094 6.08338 9.53094 5.69286 9.92146C5.30233 10.312 5.30233 10.9452 5.69286 11.3357L7.97857 13.6214C8.3691 14.0119 9.00226 14.0119 9.39279 13.6214L15.1071 7.9071Z"
                fill="white"
              />
            </svg>
          </div>
          <div className="button-copy pl-2 leading-none uppercase">
            DOWNLOAD
          </div>
        </div>
      </button> */}

      <div className="mt-10 w-1/2">
        <label
          htmlFor="formFileLg"
          className="mb-2 text-black dark:text-white lg:text-base sm:text-base font-bold text-xl  sm:py-2 max-sm:pb-1 max-md:hidden"
        >
          Submit your file
        </label>
        <input
          className="relative m-0 block w-full min-w-0 flex-auto cursor-pointer rounded border border-solid border-secondary-500 bg-transparent bg-clip-padding px-3 py-[0.32rem] text-base font-normal leading-[2.15] text-surface transition duration-300 ease-in-out file:-mx-3 file:-my-[0.32rem] file:me-3 file:cursor-pointer file:overflow-hidden file:rounded-none file:border-0 file:border-e file:border-solid file:border-inherit file:bg-transparent file:px-3  file:py-[0.32rem] file:text-surface focus:border-primary focus:text-gray-700 focus:shadow-inset focus:outline-none dark:border-white/70 dark:text-white  file:dark:text-white"
          id="formFileLg"
          type="file"
          accept="application/pdf"
          onChange={handleFileChange}
        />
      </div>
      <div className="p-1 text-red-500">Please Upload only PDF file</div>
      <button
        type="button"
        className="px-7 py-2 w-32 rounded-lg text-white bg-[#1971C2] block mt-2 hover:opacity-90 active:opacity-100 active:scale-95 mb-4"
        onClick={handleSubmit}
      >
        Submit
      </button>
    </div>
  );
};

export default AssignmentPage;
