"use client";
import VideoFooter from "@/components/Course/VideoFooter";
import React from "react";
import { fetchCourseSection, fetchLesson } from "@/actions/video";
import screenfull from "screenfull";
import VideoPlayer from "@/components/Course/VideoPlayer";
import VideoControllers from "@/components/Course/VideoControllers";
import VideoAdditional from "@/components/Course/VideoAdditional";
import VideoSidebar from "@/components/Course/VideoSidebar";
import { LessonDescription, Sections } from "@/models/courseDetails";
import { useSession } from "next-auth/react";
import Image from "next/image";

export interface VideoProps {
  id?: number;
  title: string;
  description?: string;
  url?: string;
  views?: string;
  duration?: string;
  createdAt?: string;
  isExpand?: boolean;
}

interface CourseDetailsPageProps {
  params: {
    courseSlug: string;
    slug: string;
  };
}

const CourseDetails = ({ params }: CourseDetailsPageProps) => {
  const session = useSession();
  const [videos, setVideos] = React.useState<Sections[]>([]);
  const [lesson, setLesson] = React.useState<LessonDescription>({});
  const [cinemaMood, setCinemaMood] = React.useState<boolean>(false);
  const [isAuthCourse, setIsAuthCourse] = React.useState<boolean>(false);
  const player: any = React.useRef(null);

  const handleClickFullscreen = () => {
    if (screenfull.isEnabled && player?.current) {
      screenfull.request(player?.current?.wrapper);
    }
  };

  React.useEffect(() => {
    fetchCourseSection(params.slug, (session?.data?.user as any)?.id).then(
      (res) => {
        const videoSection = res?.sections?.map((item: Sections) => {
          const obj = {
            ...item,
            courseType: res.courseType,
            isExpand:
              item.lessons.filter((i) => i.id === params.courseSlug).length > 0
                ? true
                : false,
          };
          return obj;
        });
        setVideos(videoSection);
        setIsAuthCourse(res.isAuthUserCourse);
      }
    );
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [params.courseSlug, session.data]);

  React.useEffect(() => {
    fetchLesson(params.courseSlug).then((res) => {
      setLesson(res);
    });

    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  const openAccordion = (videoItem: Sections) => {
    const tempArr = [...videos];
    const updatedCompany: Sections[] = tempArr.map((item: Sections) => {
      if (videoItem.id === item.id) {
        return { ...item, isExpand: !item.isExpand };
      } else {
        return item;
      }
    });
    setVideos(updatedCompany);
  };

  return (
    <section className=" w-full overflow-hidden overflow-x-clip border-b bg-slate-50 bg-gradient-to-t from-slate-50 to-slate-100 dark:bg-[#0B1120] dark:bg-none">
      <div className="container opacity-100 mx-auto">
        <div className="grid grid-cols-3 gap-2 transition-all lg:gap-8">
          {/* <div
            className={`col-span-full w-full space-y-8 transition-all ${
              cinemaMood ? "lg:col-span-full" : "lg:col-span-2"
            }`}
          >

            <Image
              width={0}
              height={0}
              sizes="100vw"
              alt="Course-Description"
              src={`https://media.licdn.com/dms/image/C560BAQFxilJL2SqDEA/company-logo_200_200/0/1630637333552/model_testcom_logo?e=2147483647&v=beta&t=gGMNRxSgSYgLpJm1cKz_KnG0-jZVEk8_EDg59jj9STE`}
              decoding="async"
              data-nimg="intrinsic"
              className="brightness-110 w-full h-[300px] md:h-[500px]"
            />
          </div> */}
          <div
            className={`col-span-full w-full space-y-8 transition-all ${
              cinemaMood ? "lg:col-span-full" : "lg:col-span-2"
            }`}
          >
            {videos[0]?.courseType === "MODEL_TEST" ? (
              <div className="mt-4 mx-auto relative center grid h-[35rem] max-w-lg flex-col items-center justify-center overflow-hidden rounded-lg bg-white">
                <div className="absolute inset-0 m-0 h-full w-full overflow-hidden rounded-none bg-transparent">
                    <img
                      alt="Course-Description"
                      src="/image/model_test.png"
                      decoding="async"
                      data-nimg="intrinsic"
                    />
                  {/* <Image
                    src="/image/model_test.png"
                    alt="Model Test"
                    layout="fill"
                    objectFit="cover"
                    className="absolute inset-0 h-full w-full"
                  /> */}
                </div>
              </div>
            ) : (
              <div
                className={`z-10 flex aspect-video w-full flex-col justify-center`}
              >
                <VideoPlayer player={player} lesson={lesson} />
                <VideoControllers
                  cinemaMood={cinemaMood}
                  setCinemaMood={setCinemaMood}
                  handleClickFullscreen={handleClickFullscreen}
                  videos={videos}
                  currentLesson={lesson?.id}
                  currentCourse={params.slug}
                />
              </div>
            )}

            <VideoAdditional
              lesson={lesson}
              currentCourse={params.slug}
              isAuthCourse={isAuthCourse}
              courseType={videos[0]?.courseType}
            />
            <VideoFooter lesson={lesson} />
          </div>
          <VideoSidebar
            videos={videos}
            openAccordion={openAccordion}
            currentLesson={lesson}
            currentCourse={params.slug}
            isAuthCourse={isAuthCourse}
          />
        </div>
      </div>
    </section>
  );
};

export default CourseDetails;
