/* eslint-disable @next/next/no-img-element */
import {
  fetchHigestStudent,
  fetchReportByCourseAndStudent,
  fetchReportDetails,
} from "@/actions/course-details-actions";
import { SessionProps } from "@/actions/user-info";
import { auth } from "@/auth";
import Slider from "@/components/Common/Slider";
import { USER_PROFILE } from "@/utils/helper";
import moment from "moment";
import { notFound, redirect } from "next/navigation";
import React from "react";

interface CourseIntroPageProps {
  params: {
    slug: string;
  };
}

const calculateRanking = (students: any) => {
  if (students) {
    const sortedStudents = [...students].sort((a, b) => b.mark - a.mark);
    const rankings = [
      "First",
      "Second",
      "Third",
      "Fourth",
      "Fifth",
      "Sixth",
      "Seventh",
      "Eighth",
      "Ninth",
      "Tenth",
    ];
    return sortedStudents.map((student, index) => ({
      ...student,
      ranking: rankings[index],
    }));
  }

};

const CourseReport = async ({ params }: CourseIntroPageProps) => {
  const session = (await auth()) as SessionProps;
  const result: any = await fetchReportDetails({
    courseId: params.slug,
    studentId: session?.user?.id ? session?.user?.id : undefined,
  });
  const higestStudents: any = await fetchHigestStudent({
    courseId: params.slug,
  });

  const rankings = calculateRanking(higestStudents);

  let studentCourseDetails;
  if (session?.user?.id) {
    studentCourseDetails = await fetchReportByCourseAndStudent({
      courseId: params.slug,
      studentId: session?.user?.id,
    });
  }

  if (!session?.user) {
    return redirect("/login");
  }

  function calculatePercentage(value: any, total: any) {
    return (total / value) * 100;
  }

  let totalMarks = 0;
  let marks = 0;
  let totalNegativeMarks = 0;
  let totalQuestions = 0;
  let totalCurrent = 0;
  let totalWrong = 0;

  result?.forEach((item: any) => {
    totalMarks += item?.totalMark;
    marks += item?.mark;
    totalNegativeMarks += item?.negativeMark;
    totalQuestions += item?.totalQuestion;
    totalCurrent += item?.totalCorrect;
    totalWrong += item?.totalWrong;
  });

  const totalPercentage = calculatePercentage(totalMarks, marks);

  const studentRank =
    rankings &&
      rankings.filter((item) => item._id === session?.user?.id).length > 0
      ? rankings.filter((item) => item._id === session?.user?.id)[0]
      : null;

  return (
    <div className="pt-10 pb-20">
      <div className="container">
        <div className="space-y-10">
          <div className="border-general border-b pb-3">
            <h2
              id="payment-details-heading"
              className="text-1 text-lg font-medium leading-6"
            >
              Course Report
            </h2>
            <p className="mt-1 text-base text-gray-500">
              {studentCourseDetails?.courseName}
            </p>
          </div>
          <div className="mx-auto max-w-3xl md:flex md:items-center md:justify-between md:space-x-5 lg:max-w-7xl">
            <div className="flex items-center space-x-5">
              <div className="flex-shrink-0">
                <div className="relative flex items-center ">
                  <img
                    alt="Muhammad Iqbal Hossain"
                    src={session?.user?.image || USER_PROFILE}
                    width={72}
                    height={72}
                    decoding="async"
                    data-nimg="intrinsic"
                  />
                </div>
              </div>

              <div>
                <h1 className="text-1 text-base font-bold lg:text-xl">
                  {session?.user?.name}
                </h1>
                <div className="text-1 mt-2 text-xs">
                  {Number(totalPercentage).toFixed(2)}% marks obtained
                </div>
                <div className="text-1 mt-2 text-xs">
                  Rank: {studentRank?.ranking ? studentRank?.ranking : "No Rank"}
                </div>
              </div>
            </div>
          </div>
          <div className="p-2 mt-20">
            <h1 className="section-title dark:text-white text-center p-2">
              Lesson Wise <span className="text-[#07A8ED]">Numbers</span>
            </h1>
            <div className="mx-auto">
              {/* <div className="scroll-view grid grid-cols-2 sm:grid-cols-4 md:grid-cols-4 lg:grid-cols-6 gap-2" style={{ display: 'flex', overflowX: 'scroll' }}> */}
              <Slider>
                {result?.map((res: any) => (
                  <div
                    key={res?._id}
                    style={{ minWidth: "200px" }}
                    className="border-2 border-indigo-500/75 transition ease-in-out delay-50 hover:-translate-y-1 hover:scale-105 hover:border-indigo-500/75 duration-300 relative flex h-full flex-col rounded-md border-gray-200 bg-white dark:bg-gray-800 dark:text-white-800 p-2.5 hover:border-gray-400 sm:rounded-lg sm:p-5 overflow-hidden"
                  >
                    <span className="text-sm mb-0 font-semibold text-gray-900 dark:text-gray-100 hover:text-black">
                      {res?.lessonName}
                    </span>
                    <ul className="items-center list-outside">
                      <li className="text-sm leading-normal text-gray-400 sm:block">
                        Total Ques: <strong>{res?.totalQuestion}</strong>
                      </li>
                      <li className="text-sm leading-normal text-gray-400 sm:block">
                        Total Marks: <strong>{res?.totalMark}</strong>
                      </li>
                      <li className="text-sm leading-normal text-gray-400 sm:block">
                        Obtained Marks: <strong>{res?.mark}</strong>
                      </li>
                      <li className="text-sm leading-normal text-gray-400 sm:block">
                        Total Wrong: <strong>{res?.totalWrong}</strong>
                      </li>
                    </ul>
                  </div>
                ))}
              </Slider>
              {/* </div> */}
            </div>
          </div>
          <div className="mx-auto grid max-w-3xl grid-cols-1 gap-6 lg:max-w-7xl lg:grid-flow-col-dense lg:grid-cols-3">
            <div className="space-y-6 lg:col-span-2 lg:col-start-1">
              <div className="border-general rounded-1 bg-1 border">
                <div className="px-4 py-5 sm:px-6 bg-blue-500 bg-opacity-25">
                  <h2 className="primary-highlighter text-lg font-medium">
                    Course Performance
                  </h2>
                  <p className="text-2 mt-1 max-w-2xl text-base">
                    Overall Course performance at a glance
                  </p>
                </div>
                <div className="border-general border-t px-4 py-5 sm:px-6">
                  <dl className="grid grid-cols-1 gap-x-4 gap-y-8 sm:grid-cols-2">
                    <div className="sm:col-span-1">
                      <dt className="text-2 text-base font-medium">
                        Joined on
                      </dt>
                      <dd className="text-1 mt-1 text-base">
                        {moment(studentCourseDetails?.enrollmentDate).format(
                          "DD/MM/YYYY"
                        )}
                      </dd>
                    </div>
                    <div className="sm:col-span-1">
                      <dt className="text-2 text-base font-medium">
                        Enrollment ID
                      </dt>
                      <dd className="text-1 mt-1 text-base">
                        {studentCourseDetails?._id &&
                          studentCourseDetails._id
                            .toUpperCase()
                            .replace(/-/g, "")}
                      </dd>
                    </div>
                    <div className="sm:col-span-1">
                      <dt className="text-2 text-base font-medium">
                        Tatal Quiz Perticipate
                      </dt>
                      <dd className="text-1 mt-1 text-base">
                        {result?.length}
                      </dd>
                    </div>
                    <div className="sm:col-span-1">
                      <dt className="text-2 text-base font-medium">
                        Total Marks
                      </dt>
                      <dd className="text-1 mt-1 text-base">{totalMarks}</dd>
                    </div>
                    <div className="sm:col-span-1">
                      <dt className="text-2 text-base font-medium">
                        Total Right Answer
                      </dt>
                      <dd className="text-1 mt-1 text-base">{marks}</dd>
                    </div>
                    <div className="sm:col-span-1">
                      <dt className="text-2 text-base font-medium">
                        Total marks obtained
                      </dt>
                      <dd className="text-1 mt-1 text-base">{totalCurrent}</dd>
                    </div>
                    <div className="sm:col-span-1">
                      <dt className="text-2 text-base font-medium">
                        Total Wrong Answer
                      </dt>
                      <div className="text-1 mt-1 text-base">{totalWrong}</div>
                    </div>
                    <div className="sm:col-span-1">
                      <dt className="text-2 text-base font-medium">
                        Total Negative Marks
                      </dt>
                      <div className="text-1 mt-1 text-base">
                        {totalNegativeMarks}
                      </div>
                    </div>
                  </dl>
                </div>
              </div>
            </div>
            <div className="space-y-4 lg:col-span-1 lg:col-start-3">
              <div className="border-general rounded-1 bg-1 border px-4 py-5 sm:px-6">
                {rankings &&
                  rankings?.length > 0 &&
                  rankings?.map((student, index) => (
                    <div
                      key={student?._id}
                      className={`flex items-center space-x-4 p-1.5 rounded-full bg-gray-100 dark:bg-gray-800 hover:bg-slate-300 ${
                        index !== rankings.length - 1 ? "mb-2" : ""
                      }`}
                    >
                      <span className="flex items-center justify-center w-10 h-10 shrink-0 rounded-full bg-white text-gray-900">
                        <img
                          src={USER_PROFILE}
                          alt=""
                          className="rounded-full"
                        />
                      </span>
                      <div className="flex flex-col flex-1">
                        <h3 className="text-sm font-medium">
                          {student?.studentName}
                        </h3>
                        <div className="divide-x divide-gray-200 mt-auto">
                          <span className="inline-block px-2 text-xs leading-none text-gray-400 font-normal first:pl-0">{`${student?.lessonCount} Lessons`}</span>
                          <span className="inline-block px-2 text-xs leading-none text-gray-400 font-normal first:pl-0">{`Marks: ${student?.mark}`}</span>
                          <span className="inline-block px-2 text-xs leading-none text-gray-400 font-normal first:pl-0">{`Rank: ${student?.ranking}`}</span>
                        </div>
                      </div>
                    </div>
                  ))}
              </div>
            </div>
            {/* <div className="space-y-4 lg:col-span-1 lg:col-start-3">
              <div className="border-general rounded-1 bg-1 border px-4 py-5 sm:px-6">
                <h2 id="timeline-title" className="text-1 text-lg font-medium">
                  Report Card
                </h2>
                <div className="mt-2 flow-root">
                  <div className="mt-4 flow-root">
                    <div className="scale-general flex justify-center">
                      <span>
                        <img
                          alt="Report Card"
                          src="https://learnwithsumit.com/_next/image?url=https%3A%2F%2Flws-website-assets.s3.ap-southeast-1.amazonaws.com%2Freport-cards-images%2FReport-LWSCTXN-2LBJMMFR.jpg%3Fv%3D3&w=1920&q=75"
                          decoding="async"
                          data-nimg="intrinsic"
                        />{" "}
                      </span>
                    </div>
                  </div>
                  <div className="mt-4 flex justify-center space-x-2">
                    <a href="https://lws-website-assets.s3.ap-southeast-1.amazonaws.com/report-cards/Report-LWSCTXN-2LBJMMFR.pdf?v=3">
                      <div className="mantine-Badge-filled mantine-Badge-root cursor-pointer mantine-hml3d1">
                        <span className="mantine-12wwris mantine-Badge-leftSection">
                          <svg
                            stroke="currentColor"
                            fill="currentColor"
                            stroke-width="0"
                            version="1.1"
                            viewBox="0 0 16 16"
                            height="12"
                            width="12"
                            xmlns="http://www.w3.org/2000/svg"
                          >
                            <path d="M13.156 9.211c-0.213-0.21-0.686-0.321-1.406-0.331-0.487-0.005-1.073 0.038-1.69 0.124-0.276-0.159-0.561-0.333-0.784-0.542-0.601-0.561-1.103-1.34-1.415-2.197 0.020-0.080 0.038-0.15 0.054-0.222 0 0 0.339-1.923 0.249-2.573-0.012-0.089-0.020-0.115-0.044-0.184l-0.029-0.076c-0.092-0.212-0.273-0.437-0.556-0.425l-0.171-0.005c-0.316 0-0.573 0.161-0.64 0.403-0.205 0.757 0.007 1.889 0.39 3.355l-0.098 0.239c-0.275 0.67-0.619 1.345-0.923 1.94l-0.040 0.077c-0.32 0.626-0.61 1.157-0.873 1.607l-0.271 0.144c-0.020 0.010-0.485 0.257-0.594 0.323-0.926 0.553-1.539 1.18-1.641 1.678-0.032 0.159-0.008 0.362 0.156 0.456l0.263 0.132c0.114 0.057 0.234 0.086 0.357 0.086 0.659 0 1.425-0.821 2.48-2.662 1.218-0.396 2.604-0.726 3.819-0.908 0.926 0.521 2.065 0.883 2.783 0.883 0.128 0 0.238-0.012 0.327-0.036 0.138-0.037 0.254-0.115 0.325-0.222 0.139-0.21 0.168-0.499 0.13-0.795-0.011-0.088-0.081-0.196-0.157-0.271zM3.307 12.72c0.12-0.329 0.596-0.979 1.3-1.556 0.044-0.036 0.153-0.138 0.253-0.233-0.736 1.174-1.229 1.642-1.553 1.788zM7.476 3.12c0.212 0 0.333 0.534 0.343 1.035s-0.107 0.853-0.252 1.113c-0.12-0.385-0.179-0.992-0.179-1.389 0 0-0.009-0.759 0.088-0.759v0zM6.232 9.961c0.148-0.264 0.301-0.543 0.458-0.839 0.383-0.724 0.624-1.29 0.804-1.755 0.358 0.651 0.804 1.205 1.328 1.649 0.065 0.055 0.135 0.111 0.207 0.166-1.066 0.211-1.987 0.467-2.798 0.779v0zM12.952 9.901c-0.065 0.041-0.251 0.064-0.37 0.064-0.386 0-0.864-0.176-1.533-0.464 0.257-0.019 0.493-0.029 0.705-0.029 0.387 0 0.502-0.002 0.88 0.095s0.383 0.293 0.318 0.333v0z"></path>
                            <path d="M14.341 3.579c-0.347-0.473-0.831-1.027-1.362-1.558s-1.085-1.015-1.558-1.362c-0.806-0.591-1.197-0.659-1.421-0.659h-7.75c-0.689 0-1.25 0.561-1.25 1.25v13.5c0 0.689 0.561 1.25 1.25 1.25h11.5c0.689 0 1.25-0.561 1.25-1.25v-9.75c0-0.224-0.068-0.615-0.659-1.421v0zM12.271 2.729c0.48 0.48 0.856 0.912 1.134 1.271h-2.406v-2.405c0.359 0.278 0.792 0.654 1.271 1.134v0zM14 14.75c0 0.136-0.114 0.25-0.25 0.25h-11.5c-0.135 0-0.25-0.114-0.25-0.25v-13.5c0-0.135 0.115-0.25 0.25-0.25 0 0 7.749-0 7.75 0v3.5c0 0.276 0.224 0.5 0.5 0.5h3.5v9.75z"></path>
                          </svg>
                        </span>
                        <span className="mantine-h9iq4m mantine-Badge-inner">
                          PDF
                        </span>
                      </div>
                    </a>
                    <a href="https://lws-website-assets.s3.ap-southeast-1.amazonaws.com/report-cards-images/Report-LWSCTXN-2LBJMMFR.jpg?v=3">
                      <div className="mantine-Badge-filled mantine-Badge-root cursor-pointer mantine-1akqsza">
                        <span className="mantine-12wwris mantine-Badge-leftSection">
                          <svg
                            stroke="currentColor"
                            fill="currentColor"
                            stroke-width="0"
                            viewBox="0 0 1024 1024"
                            height="12"
                            width="12"
                            xmlns="http://www.w3.org/2000/svg"
                          >
                            <path d="M874.6 301.8L596.8 21.3c-4.5-4.5-9.4-8.3-14.7-11.5-1.4-.8-2.8-1.6-4.3-2.3-.9-.5-1.9-.9-2.8-1.3-9-4-18.9-6.2-29-6.2H201c-39.8 0-73 32.2-73 72v880c0 39.8 33.2 72 73 72h623c39.8 0 71-32.2 71-72V352.5c0-19-7-37.2-20.4-50.7zM583 110.4L783.8 312H583V110.4zM823 952H200V72h311v240c0 39.8 33.2 72 73 72h239v568zM350 696.5c0 24.2-7.5 31.4-21.9 31.4-9 0-18.4-5.8-24.8-18.5L272.9 732c13.4 22.9 32.3 34.2 61.3 34.2 41.6 0 60.8-29.9 60.8-66.2V577h-45v119.5zM501.3 577H437v186h44v-62h21.6c39.1 0 73.1-19.6 73.1-63.6 0-45.8-33.5-60.4-74.4-60.4zm-.8 89H481v-53h18.2c21.5 0 33.4 6.2 33.4 24.9 0 18.1-10.5 28.1-32.1 28.1zm182.5-9v36h30v30.1c-4 2.9-11 4.7-17.7 4.7-34.3 0-50.7-21.4-50.7-58.2 0-36.1 19.7-57.4 47.1-57.4 15.3 0 25 6.2 34 14.4l23.7-28.3c-12.7-12.8-32.1-24.2-59.2-24.2-49.6 0-91.1 35.3-91.1 97 0 62.7 40 95.1 91.5 95.1 25.9 0 49.2-10.2 61.5-22.6V657H683z"></path>
                          </svg>
                        </span>
                        <span className="mantine-h9iq4m mantine-Badge-inner">
                          JPG
                        </span>
                      </div>
                    </a>
                  </div>
                </div>
              </div>
            </div> */}
          </div>
        </div>
      </div>
    </div>
  );
};

export default CourseReport;
