/* eslint-disable @next/next/no-img-element */
import React from "react";
import { auth } from "@/auth";
import { Hind_Siliguri } from "next/font/google";
import { CourseOverviewProps } from "@/models/home";
import { fetchCourseDetails } from "@/actions/course-details-actions";
import { SessionProps, fetchAuthUser } from "@/actions/user-info";
import { UserDetailsProps } from "@/models/user";
import { redirect } from "next/navigation";
import moment from "moment";
import clientAxios from "@/services/config";
import { COURSE_API } from "@/services/api-end-point/courses";

const HindFont = Hind_Siliguri({
  weight: "400",
  subsets: ["latin"],
});

interface CourseEnrollmentPageProps {
  params: {
    slug: string;
  };
}

export default async function Enrollment({
  params,
}: CourseEnrollmentPageProps) {
  const session = (await auth()) as SessionProps;
  const result: CourseOverviewProps = await fetchCourseDetails({
    courseId: params.slug,
  });
  const userInfo: UserDetailsProps = await fetchAuthUser();

  if (!session?.user) {
    redirect("/login");
  }

   const handleSubmitEnrollment = async (formData: FormData) => {
     "use server";
     const transactionId = formData.get("transactionId") as string;
     const transactionType = formData.get("transactionType") as string;
     const data = {
       studentId: userInfo?.id,
       studentName: userInfo?.name,
       courseId: result.course._id,
       courseName: result.course.name,
       instructorId: result.course.instructorId,
       instructorName: result.course.instructorName,
       organizationId: result.course.organizationId,
       studentMobileNumber: userInfo?.phone,
       amount: result.course.price - (result.course?.discount || 0),
       transactionType,
       isAmountPaid: true,
       status: "Approved",
       enrollmentDate: moment().format("YYYY-MM-DD"),
       paymentDate: moment().format("YYYY-MM-DD"),
       discountAmount: result.course.discount,
       transactionId,
     };
     // try {
     const res = await clientAxios.post(
       `${COURSE_API.course_enrollment_by_student}`,
       data
     );
     if (res) {
       return redirect("/profile/enrollment");
     } else {
       console.log("something went wrong");
       return;
     }
   };

  return (
    <section className="lg:min-h-[calc(100vh_-_347px)]">
      <div className="py-10 lg:py-20">
        <div className="container mx-auto">
          <div className="flex flex-col gap-6 lg:flex-row lg:gap-20">
            <div className="w-full space-y-8">
              <div>
                <h1 className="section-title text-center dark:text-white">
                  <span className="primary-highlighter">এনরোলমেন্ট</span> করুন
                </h1>
                <p className="subtitle mx-auto w-full text-center">
                  আপনার তথ্য কারো সাথে শেয়ার করবেন না
                </p>
              </div>
              <form className="space-y-8" action={handleSubmitEnrollment}>
                <div className={`${HindFont.className}`}>
                  <label
                    htmlFor="transactionId"
                    id="transactionId-label"
                    className="mantine-4yl2fc mantine-TextInput-label !text-black dark:!text-white"
                  >
                    ট্রানজেকশন আইডি
                    <span
                      className="mantine-qrh19y mantine-TextInput-required"
                      aria-hidden="true"
                    >
                      {" "}
                      *
                    </span>
                  </label>
                  {/* <div className="mantine-Text-root mantine-TextInput-description mantine-vitztl !text-black dark:!text-white">
                    যে ইমেইল এড্রেস দিয়ে আপনি নিবন্ধন করেছিলেন।
                  </div> */}
                  <div className="mantine-TextInput-wrapper relative">
                    <input
                      name="transactionId"
                      aria-label="transactionId"
                      placeholder="TS345FD..."
                      id="transactionId"
                      type="text"
                      required
                      aria-invalid="false"
                      className="mantine-TextInput-filledVariant dark:bg-slate-800 mantine-TextInput-input mantine-7i89j6 outline-none"
                    />
                  </div>
                </div>
                <div className={`${HindFont.className}`}>
                  <label
                    htmlFor="transactionType"
                    id="transactionType-label"
                    className="mantine-4yl2fc mantine-PasswordInput-label !text-black dark:!text-white"
                  >
                    ট্রানজেকশন টাইপ
                    <span
                      className="mantine-qrh19y mantine-PasswordInput-required"
                      aria-hidden="true"
                    >
                      {" "}
                      *
                    </span>
                  </label>
                  {/* <div className="mantine-Text-root mantine-PasswordInput-description mantine-vitztl !text-black dark:!text-white">
                    পাসওয়ার্ড কমপক্ষে ৮ অক্ষরের হতে হবে এবং সেখানে কমপক্ষে 1 টি
                    লেটার এবং 1 টি নাম্বার থাকতেই হবে।
                  </div> */}
                  <div className="mantine-PasswordInput-wrapper relative">
                    <div
                      aria-invalid="false"
                      className="mantine-PasswordInput-filledVariant dark:bg-slate-800 mantine-PasswordInput-input mantine-PasswordInput-input mantine-1is1kg1"
                    >
                      <input
                        name="transactionType"
                        type="text"
                        className="mantine-f6gkdg mantine-PasswordInput-innerInput outline-none"
                        id="password"
                        placeholder="BKash"
                        required
                        aria-label="transactionType"
                      />
                    </div>
                    <div className="mantine-o3oqoy mantine-PasswordInput-rightSection">
                      <button
                        className="mantine-ActionIcon-hover mantine-ActionIcon-root mantine-PasswordInput-visibilityToggle mantine-122en5e"
                        type="button"
                        aria-hidden="true"
                      >
                        <svg
                          width="15"
                          height="15"
                          viewBox="0 0 15 15"
                          fill="none"
                          xmlns="http://www.w3.org/2000/svg"
                        >
                          <path
                            d="M7.5 11C4.80285 11 2.52952 9.62184 1.09622 7.50001C2.52952 5.37816 4.80285 4 7.5 4C10.1971 4 12.4705 5.37816 13.9038 7.50001C12.4705 9.62183 10.1971 11 7.5 11ZM7.5 3C4.30786 3 1.65639 4.70638 0.0760002 7.23501C-0.0253338 7.39715 -0.0253334 7.60288 0.0760014 7.76501C1.65639 10.2936 4.30786 12 7.5 12C10.6921 12 13.3436 10.2936 14.924 7.76501C15.0253 7.60288 15.0253 7.39715 14.924 7.23501C13.3436 4.70638 10.6921 3 7.5 3ZM7.5 9.5C8.60457 9.5 9.5 8.60457 9.5 7.5C9.5 6.39543 8.60457 5.5 7.5 5.5C6.39543 5.5 5.5 6.39543 5.5 7.5C5.5 8.60457 6.39543 9.5 7.5 9.5Z"
                            fill="currentColor"
                            fillRule="evenodd"
                            clipRule="evenodd"
                          ></path>
                        </svg>
                      </button>
                    </div>
                  </div>
                </div>
                <div className="mantine-Group-root mantine-19jxmdp">
                  <button
                    className="mantine-Button-filled bg-slate-800 dark:bg-secondary2 hover:bg-slate-700 dark:hover:bg-secondary1 text-white mantine-Button-root mantine-Group-child mantine-13xrvzk"
                    type="submit"
                  >
                    <div className="mantine-3xbgk5 mantine-Button-inner">
                      <span className="mantine-qo1k2 mantine-Button-label">
                        জমা দিন
                      </span>
                    </div>
                  </button>
                </div>
              </form>
            </div>

            <div className="w-full">
              <div className="flex h-full w-full items-center justify-center">
                <div>
                  <span>
                    <img
                      alt="Peep"
                      src="/image/login.png"
                      decoding="async"
                      data-nimg="intrinsic"
                    />
                  </span>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>
    </section>
  );
}
