import {
  fetchCourseDetails,
  fetchCourseDetailsById,
} from "@/actions/course-details-actions";
import CourseDetailsPlayer from "@/components/CourseDetails/CourseDetailsPlayer";
import CourseInstructor from "@/components/CourseDetails/CourseInstractor";
import CourseOverview from "@/components/CourseDetails/CourseOverview";
import CourseSummery from "@/components/CourseDetails/CourseSummery";
import PageOverlay from "@/components/CourseDetails/PageOverlay";
import { CourseOverviewProps, CourseVideoProps } from "@/models/home";
import Image from "next/image";
import Link from "next/link";
import { notFound } from "next/navigation";
import React from "react";
import courseDescriptionsImage from "@/asstes/image/course-details-1.jpg";
import openBook from "@/asstes/svg/book-open-black.svg";
import ReactPlayer from "react-player";
import CurseRoutine from "@/components/CourseDetails/CurseRoutine";
import { auth } from "@/auth";
import { SessionProps } from "@/actions/user-info";
import FaqComponent from "@/components/CourseDetails/FaqComponent";
import CourseFeedback from "@/components/CourseDetails/CourseFeedback";

interface CourseIntroPageProps {
  params: {
    slug: string;
  };
}

const CourseIntro = async ({ params }: CourseIntroPageProps) => {
  const session = (await auth()) as SessionProps;
  const result: CourseOverviewProps = await fetchCourseDetails({
    courseId: params.slug,
    studentId: session?.user?.id ? session?.user?.id : undefined,
  });
  const courseDetails: CourseOverviewProps = await fetchCourseDetailsById(
    params.slug
  );

  if (!result?.course?._id) {
    return notFound();
  }

  const parsedInfo = JSON.parse(result?.course?.info || "{}");
  const courseDescriptions = parsedInfo?.courseDescriptions;

  return (
    <div>
      <section className="border-general relative w-full overflow-hidden overflow-x-clip border-b bg-slate-50 bg-gradient-to-t from-slate-50 to-slate-100 dark:bg-[#0B1120] dark:bg-none">
        <PageOverlay />
        <div className="w-full bg-pattern py-2 dark:bg-dpattern lg:flex lg:h-full lg:items-center ">
          <div className="container opacity-100 mx-auto">
            <div className="flex flex-col items-start gap-10 lg:flex-row lg:gap-15">
              <div className="flex w-full mt-2 flex-col justify-center">
                <div className="flex flex-col space-y-4 text-center lg:text-left">
                  <div className="!space-x-4 flex justify-center">
                    {/* <Image
                      width={300}
                      height={150}
                      alt="Course-Description"
                      src={courseDescriptionsImage}
                      decoding="async"
                      data-nimg="intrinsic"
                      className="brightness-110"
                    /> */}
                     <img
                      alt="Course-Description"
                      src="/image/course-details-1.jpg"
                      decoding="async"
                      data-nimg="intrinsic"
                      width={300}
                      height={150}
                    />
                  </div>
                  <h1 className="hero-title text-3xl text-[#07A8ED]">
                    {result.course.name}
                  </h1>
                </div>
                <div className="text-1 text-medium mt-8 text-center lg:text-left">
                  <div
                    dangerouslySetInnerHTML={{
                      __html: result.course.description,
                    }}
                  />
                </div>
                <div className="mx-auto mt-10 flex gap-4 lg:mx-0">
                  <div className="lg:block z-20">
                    <Link
                      href={`/${result.course?._id}/course/${result.lesson?._id}`}
                      className="flex flex-wrap gap-1 border border-gray-400 rounded justify-center items-center p-2"
                    >
                      <span className="">
                        <svg
                          stroke="currentColor"
                          fill="none"
                          strokeWidth="2"
                          viewBox="0 0 24 24"
                          strokeLinecap="round"
                          strokeLinejoin="round"
                          className="h-5 w-5"
                          height="1em"
                          width="1em"
                          xmlns="http://www.w3.org/2000/svg"
                        >
                          <polygon points="23 7 16 12 23 17 23 7"></polygon>
                          <rect
                            x="1"
                            y="5"
                            width="15"
                            height="14"
                            rx="2"
                            ry="2"
                          ></rect>
                        </svg>
                      </span>
                      <span className="mantine-qo1k2 mantine-Button-label">
                        কোর্সের বিস্তারিত
                      </span>
                    </Link>
                  </div>
                </div>
                {result.courseRoutine && result.courseRoutine?.isActive && (
                  <CurseRoutine routine={result.courseRoutine} />
                )}
              </div>

              <div className="justify-center col-span-full w-full">
                <div className=" col-span-full w-full space-y-8 transition-all lg:col-span-2">
                  <div className="relative">
                    {result?.course?.courseType === "MODEL_TEST" ? (
                      // <Image
                      //   width={0}
                      //   height={0}
                      //   sizes="100vw"
                      //   alt="Course-Description"
                      //   src='/image/model_test.png'
                      //   decoding="async"
                      //   data-nimg="intrinsic"
                      //   className="brightness-110 w-full h-[200px] md:h-[500px]"
                      // />
                      <img
                      alt="Course-Description"
                      src="/image/model_test.png"
                      decoding="async"
                      data-nimg="intrinsic"
                    />
                    ) : (
                      <CourseDetailsPlayer
                        videoUrl={result.course.courseOverview}
                      />
                    )}
                  </div>
                </div>
                <div
                  className={
                    result?.course?.courseType !== "MODEL_TEST"
                      ? "mt-32 md:mt-0"
                      : ""
                  }
                >
                  <h1 className="text-lg font-bold p-2 text-center">{`মাত্র ৳ ${
                    result.course.price - (result.course?.discount || 0)
                  } /-`}</h1>

                  <figure className="bg-slate-100 rounded-xl dark:bg-slate-800 mt-2">
                    {result.isAuthUser ? (
                      <Link
                        href={`/${result.course?._id}/course/${result.lesson?._id}`}
                      >
                        <button className="font-bold rounded-md bg-green-500 p-3 whitespace-nowrap text-base text-white w-full hover:bg-green-600 focus:outline-none focus:ring-2 focus:ring-green-700 focus:ring-opacity-50">
                          কোর্সটির বিস্তারিত দেখুন
                        </button>
                      </Link>
                    ) : (
                      <Link href={`/${result.course._id}/enrollment`}>
                        <button className="font-bold rounded-md bg-green-500 p-3 whitespace-nowrap text-base text-white w-full hover:bg-green-600 focus:outline-none focus:ring-2 focus:ring-green-700 focus:ring-opacity-50">
                          কোর্সটি কিনুন
                        </button>
                      </Link>
                    )}

                    {courseDescriptions?.length > 0 && (
                      <div className="pt-4 md:p-6 text-center md:text-left space-y-4">
                        {courseDescriptions?.map(
                          (courseDescription: string, index: number) => (
                            <blockquote
                              className="flex items-center"
                              key={index}
                            >
                              {courseDescription && (
                                <Image
                                  src={openBook}
                                  alt="Icon"
                                  width={25}
                                  height={25}
                                />
                              )}
                              <p className="text-lg font-medium p-1">
                                {courseDescription}
                              </p>
                            </blockquote>
                          )
                        )}
                      </div>
                    )}
                  </figure>
                </div>
              </div>
            </div>
          </div>
        </div>
      </section>
      <CourseSummery />
      <CourseOverview course={courseDetails} />
      {parsedInfo?.faqQuestions?.length > 0 && (
        <FaqComponent faqQuestion={parsedInfo?.faqQuestions} />
      )}

      <CourseInstructor instructor={result.courseInstructor} />
      {session?.user?.id && (
        <CourseFeedback course={result.course} session={session} />
      )}
    </div>
  );
};

export default CourseIntro;
