import { initializeApp } from "firebase/app";
import { getAuth, signInWithPhoneNumber, signInWithCredential, PhoneAuthProvider } from "firebase/auth";
import { RecaptchaVerifier } from "firebase/auth";
import { useState } from "react";
import { useSession } from "next-auth/react";
import { redirect } from "next/navigation";
import * as actions from "@/actions";
import { useFormState } from "react-dom";

export const validatePhone = (value: any) => {
    if (!value) {
        return 'Phone is required'
    } else if (!/^\+?\d+$/.test(value)) {
        return 'Phone number is invalid'
    } else if (value.startsWith('+88')) {
        if (value.length !== 14) {
            return 'Phone number must be exactly 11 or 14 digits for +88 prefix'
        }
    } else if (value.length !== 11) {
        return 'Phone number must be exactly 11 digits'
    }
    return value;
}

// Your web app's Firebase configuration
const firebaseConfig = {
    apiKey: "AIzaSyDC0ck7lUqLOQ4fh0WGXRB4Sxqa7W7cfwQ",
    authDomain: "learning-management-59290.firebaseapp.com",
    projectId: "learning-management-59290",
    storageBucket: "learning-management-59290.appspot.com",
    messagingSenderId: "167500419842",
    appId: "1:167500419842:web:85a130ca53de520d70281b",
    measurementId: "G-77MWVT7QRK"
};

// Initialize Firebase
const app = initializeApp(firebaseConfig);
const auth = getAuth(app);

const OTPVerification = () => {
    const [phoneNumber, setPhoneNumber] = useState('');
    const [phone, setPhone] = useState('');
    const [verificationId, setVerificationId] = useState('');

    const [otp, setOtp] = useState('');
    const [formState, action] = useFormState(actions.credentialsSignIn, {
        errors: {},
    });
    const session = useSession();
    if (session?.data?.user) {
        redirect('/')
    }

    const handleSendOTP = async () => {
        try {
            const appVerifier = new RecaptchaVerifier(auth, 'recaptcha', {});
            const validatePhone = phoneNumber?.startsWith('+88') ? phoneNumber : '+88' + phoneNumber;
            const confirmation = await signInWithPhoneNumber(auth, validatePhone, appVerifier);
            setVerificationId(confirmation.verificationId);
            localStorage.setItem('verificationId', confirmation.verificationId);
            alert('OTP sent successfully!');
        } catch (error) {
            console.error('Error sending OTP:', error);
        }
    };

    const handleVerifyOTP = async () => {
        try {
            const verificationId = localStorage.getItem('verificationId');
            const authCredential = PhoneAuthProvider.credential(verificationId!, otp);
            const res = await signInWithCredential(auth, authCredential);
            setPhone(res.user.phoneNumber!);
            action
            localStorage.removeItem('verificationId');
            alert('OTP verified successfully!');
        } catch (error) {
            console.error('Error verifying OTP:', error);
        }
    };

    return (
        <div className="flex flex-col items-center justify-center mt-10">
            {!verificationId &&
                (
                    <div className="gap-2">
                        <input type="text" placeholder="Enter phone number" value={phoneNumber} onChange={(e) => setPhoneNumber(e.target.value)} className="border border-gray-300 px-4 py-2 rounded-md mb-4" />
                        <button onClick={handleSendOTP} className="mb-4 bg-blue-500 text-white px-4 py-2 rounded-md hover:bg-blue-600">Send OTP</button>
                        <div id="recaptcha" className="p-2"></div>

                    </div>
                )}

            {
                verificationId &&
                (
                    <form onSubmit={handleVerifyOTP}>
                        <input type="text" disabled={true} name="phone" value={phone}  className="border border-gray-300 px-4 py-2 rounded-md mb-4" />
                        <input type="text" placeholder="Enter OTP" name="otp" value={otp} onChange={(e) => setOtp(e.target.value)} className="border border-gray-300 px-4 py-2 rounded-md mb-4" />
                        <button type="submit" className="mb-4 bg-blue-500 text-white px-4 py-2 rounded-md hover:bg-blue-600">Verify OTP</button>
                    </form>
                )
            }

        </div>
    );
};

export default OTPVerification;
