/* eslint-disable @next/next/no-img-element */
"use client";
import React, { useState } from "react";
import * as actions from "@/actions";
import { redirect } from "next/navigation";
import { Hind_Siliguri } from "next/font/google";
import Link from "next/link";
import { useFormState } from "react-dom";
import { useSession } from "next-auth/react";

const HindFont = Hind_Siliguri({
  weight: "400",
  subsets: ["latin"],
});

export default function Login() {
  const [showPass, setShowPass] = useState(false)
  const [formState, action] = useFormState(actions.credentialsSignIn, {
    errors: {},
  });
  const session = useSession();
  if (session?.data?.user) {
    redirect('/')
  }

  return (
    <section className="lg:min-h-[calc(100vh_-_347px)]">
      <div className="py-10 lg:py-20">
        <div className="container mx-auto">
          <div className="flex flex-col gap-6 lg:flex-row lg:gap-20">
            <div className="w-full space-y-8">
              <div>
                <h1 className="section-title text-center dark:text-white">
                  <span className="primary-highlighter">লগইন</span> করুন
                </h1>
                <p className="subtitle mx-auto w-full text-center dark:text-gray-300">
                  আপনার লগইন তথ্য কারো সাথে শেয়ার করবেন না
                </p>
              </div>
              <form className="space-y-8" action={action}>
                <div className={`${HindFont.className}`}>
                  <label
                    htmlFor="email"
                    id="email-label"
                    className="mantine-4yl2fc mantine-TextInput-label !text-black dark:!text-white"
                  >
                    আপনার ইমেইল এড্রেস
                    <span
                      className="mantine-qrh19y mantine-TextInput-required"
                      aria-hidden="true"
                    >
                      {" "}
                      *
                    </span>
                  </label>
                  <div className="mantine-Text-root mantine-TextInput-description mantine-vitztl !text-black dark:!text-white">
                    যে ইমেইল এড্রেস দিয়ে আপনি নিবন্ধন করেছিলেন।
                  </div>
                  <div className="mantine-TextInput-wrapper relative">
                    <input
                      name="email"
                      aria-label="Your email address"
                      placeholder="boss@gmail.com"
                      id="email"
                      type="text"
                      aria-invalid="false"
                      className="mantine-TextInput-filledVariant dark:bg-slate-800 mantine-TextInput-input mantine-7i89j6 outline-none"
                    />
                  </div>
                </div>
                <div className={`${HindFont.className}`}>
                  <label
                    htmlFor="password"
                    id="password-label"
                    className="mantine-4yl2fc mantine-PasswordInput-label !text-black dark:!text-white"
                  >
                    পাসওয়ার্ড দিন
                    <span
                      className="mantine-qrh19y mantine-PasswordInput-required"
                      aria-hidden="true"
                    >
                      {" "}
                      *
                    </span>
                  </label>
                  <div className="mantine-Text-root mantine-PasswordInput-description mantine-vitztl !text-black dark:!text-white">
                    পাসওয়ার্ড কমপক্ষে ৮ অক্ষরের হতে হবে এবং সেখানে কমপক্ষে 1 টি
                    লেটার এবং 1 টি নাম্বার থাকতেই হবে।
                  </div>
                  <div className="mantine-PasswordInput-wrapper relative">
                    <div
                      aria-invalid="false"
                      className="mantine-PasswordInput-filledVariant dark:bg-slate-800 mantine-PasswordInput-input mantine-PasswordInput-input mantine-1is1kg1"
                    >
                      <input
                        name="password"
                        type={showPass ? "text" : "password"}
                        className="mantine-f6gkdg mantine-PasswordInput-innerInput outline-none"
                        id="password"
                        placeholder="anyPassword1971"
                        aria-label="Your password"
                      />
                    </div>
                    <div className="mantine-o3oqoy mantine-PasswordInput-rightSection">
                      <button
                        className="mantine-ActionIcon-hover mantine-ActionIcon-root mantine-PasswordInput-visibilityToggle mantine-122en5e"
                        aria-hidden="true"
                        type="button"
                        onClick={() => setShowPass(!showPass)}
                      >
                        {showPass ? (
                          <svg
                            width="15"
                            height="15"
                            viewBox="0 0 15 15"
                            fill="none"
                            xmlns="http://www.w3.org/2000/svg"
                          >
                            <path
                              d="M13.3536 2.35355C13.5488 2.15829 13.5488 1.84171 13.3536 1.64645C13.1583 1.45118 12.8417 1.45118 12.6464 1.64645L10.6828 3.61012C9.70652 3.21671 8.63759 3 7.5 3C4.30786 3 1.65639 4.70638 0.0760002 7.23501C-0.0253338 7.39715 -0.0253334 7.60288 0.0760014 7.76501C0.902945 9.08812 2.02314 10.1861 3.36061 10.9323L1.64645 12.6464C1.45118 12.8417 1.45118 13.1583 1.64645 13.3536C1.84171 13.5488 2.15829 13.5488 2.35355 13.3536L4.31723 11.3899C5.29348 11.7833 6.36241 12 7.5 12C10.6921 12 13.3436 10.2936 14.924 7.76501C15.0253 7.60288 15.0253 7.39715 14.924 7.23501C14.0971 5.9119 12.9769 4.81391 11.6394 4.06771L13.3536 2.35355ZM9.90428 4.38861C9.15332 4.1361 8.34759 4 7.5 4C4.80285 4 2.52952 5.37816 1.09622 7.50001C1.87284 8.6497 2.89609 9.58106 4.09974 10.1931L9.90428 4.38861ZM5.09572 10.6114L10.9003 4.80685C12.1039 5.41894 13.1272 6.35031 13.9038 7.50001C12.4705 9.62183 10.1971 11 7.5 11C6.65241 11 5.84668 10.8639 5.09572 10.6114Z"
                              fill="currentColor"
                              fillRule="evenodd"
                              clipRule="evenodd"
                            ></path>
                          </svg>
                        ) : (
                          <svg
                            width="15"
                            height="15"
                            viewBox="0 0 15 15"
                            fill="none"
                            xmlns="http://www.w3.org/2000/svg"
                          >
                            <path
                              d="M7.5 11C4.80285 11 2.52952 9.62184 1.09622 7.50001C2.52952 5.37816 4.80285 4 7.5 4C10.1971 4 12.4705 5.37816 13.9038 7.50001C12.4705 9.62183 10.1971 11 7.5 11ZM7.5 3C4.30786 3 1.65639 4.70638 0.0760002 7.23501C-0.0253338 7.39715 -0.0253334 7.60288 0.0760014 7.76501C1.65639 10.2936 4.30786 12 7.5 12C10.6921 12 13.3436 10.2936 14.924 7.76501C15.0253 7.60288 15.0253 7.39715 14.924 7.23501C13.3436 4.70638 10.6921 3 7.5 3ZM7.5 9.5C8.60457 9.5 9.5 8.60457 9.5 7.5C9.5 6.39543 8.60457 5.5 7.5 5.5C6.39543 5.5 5.5 6.39543 5.5 7.5C5.5 8.60457 6.39543 9.5 7.5 9.5Z"
                              fill="currentColor"
                              fillRule="evenodd"
                              clipRule="evenodd"
                            ></path>
                          </svg>
                        )}
                      </button>
                    </div>
                  </div>
                </div>
                <div className="mantine-Group-root mantine-19jxmdp">
                  <button
                    className="mantine-Button-filled bg-slate-800 dark:bg-secondary2 hover:bg-slate-700 dark:hover:bg-secondary1 text-white mantine-Button-root mantine-Group-child mantine-13xrvzk"
                    type="submit"
                  >
                    <div className="mantine-3xbgk5 mantine-Button-inner">
                      <span className="mantine-qo1k2 mantine-Button-label">
                        লগইন করুন
                      </span>
                    </div>
                  </button>
                  <a
                    className="text-1 primary-highlighter text-sm"
                    href="/forget-password"
                  >
                    পাসওয়ার্ড ভুলে গেছেন?
                  </a>
                </div>
              </form>
              {formState.errors._form ? (
                <div className="rounded p-2 bg-red-200 border border-red-400">
                  {formState.errors._form?.join(", ")}
                </div>
              ) : null}
              <p className="text-[#464956] text-sm font-light pt-3 dark:!text-white">
                যদি আপনার অ্যাকাউন্ট না থাকে!
                <Link
                  href={"/registration"}
                  className="text-theme_color text-sm font-bold pl-1 text-[#4287f5]"
                >
                  অনুগ্রহ করে সাইন আপ করুন
                </Link>
              </p>
              <div className="mantine-TextInput-wrapper relative">
                <form action={actions.signIn}>
                  <button
                    // onClick={() => login()}
                    type="submit"
                    className="bg-gradient-to-l from-[#028FF0] via-[#0F9D58] to-[#EB4132] shadow-bmpshadow rounded-md p-[1px] mt-6 w-full"
                  >
                    <div className="bg-white py-[10.5px] px-8 flex items-center justify-center gap-6 rounded-md w-full h-full">
                      <span>
                        <svg
                          height="28"
                          aria-hidden="true"
                          viewBox="0 0 16 16"
                          version="1.1"
                          width="28"
                          data-view-component="true"
                        >
                          <path d="M8 0c4.42 0 8 3.58 8 8a8.013 8.013 0 0 1-5.45 7.59c-.4.08-.55-.17-.55-.38 0-.27.01-1.13.01-2.2 0-.75-.25-1.23-.54-1.48 1.78-.2 3.65-.88 3.65-3.95 0-.88-.31-1.59-.82-2.15.08-.2.36-1.02-.08-2.12 0 0-.67-.22-2.2.82-.64-.18-1.32-.27-2-.27-.68 0-1.36.09-2 .27-1.53-1.03-2.2-.82-2.2-.82-.44 1.1-.16 1.92-.08 2.12-.51.56-.82 1.28-.82 2.15 0 3.06 1.86 3.75 3.64 3.95-.23.2-.44.55-.51 1.07-.46.21-1.61.55-2.33-.66-.15-.24-.6-.83-1.23-.82-.67.01-.27.38.01.53.34.19.73.9.82 1.13.16.45.68 1.31 2.69.94 0 .67.01 1.3.01 1.49 0 .21-.15.45-.55.38A7.995 7.995 0 0 1 0 8c0-4.42 3.58-8 8-8Z"></path>
                        </svg>
                      </span>
                      <span className="text-black md:text-base text-sm font-archivo font-normal">
                        Continue with GItHub
                      </span>
                    </div>
                  </button>
                </form>
              </div>
            </div>

            <div className="w-full">
              <div className="flex h-full w-full items-center justify-center">
                <div>
                  <span>
                    <img
                      alt="Peep"
                      src="/image/login.png"
                      decoding="async"
                      data-nimg="intrinsic"
                    />
                  </span>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>
    </section>
  );
}
