import NextAuth from "next-auth";
import Github from "next-auth/providers/github";
import CredentialsProvider from "next-auth/providers/credentials";

const GITHUB_CLIENT_ID = process.env.GITHUB_CLIENT_ID;
const GITHUB_CLIENT_SECRET = process.env.GITHUB_CLIENT_SECRET;

if (!GITHUB_CLIENT_ID || !GITHUB_CLIENT_SECRET) {
  throw new Error("Missing GITHUB_CLIENT_ID or GITHUB_CLIENT");
}

export const {
  handlers: { GET, POST },
  auth,
  signOut,
  signIn,
} = NextAuth({
  providers: [
    Github({
      clientId: GITHUB_CLIENT_ID,
      clientSecret: GITHUB_CLIENT_SECRET,
    }),
    CredentialsProvider({
      async authorize(credentials: any) {
        // const authResponse = await fetch("http://localhost:6543/users/login", {
        //   method: "POST",
        //   headers: {
        //     "Content-Type": "application/json",
        //   },
        //   body: JSON.stringify(credentials),
        // });
        // if (!authResponse.ok) {
        //   return null;
        // }

        // const user = await authResponse.json();
        return {
          name: credentials.name,
          email: credentials.email,
          image: credentials.image,
          id: credentials.id,
          token: credentials.accessToken,
        };
      },
    }),
  ],
  callbacks: {
    jwt: async ({ token, trigger, session, user, account, profile }) => {
      // console.log(token, user, account, profile);
        if (trigger === "update" && session?.image) {
          token.image = session.image;
        }
      return { ...token, ...user };
    },
    // async jwt({ token, trigger, session }) {
    //   // console.log('aaaaaaaaaaaa', token, trigger, session);
      
    //   if (trigger === "update" && session?.image) {
    //     token.image = session.image;
    //   }
    //   // session.image = token.image;
    //   console.log(token);
      

    //   return token;
    // },
    async session({ session, token }: any) {
      // console.log(session, token);
      
      if (session && token) {
        session.user.token = token.token;
        session.user.image = token.image || "";
        session.user.id = token.id;
      }
      return session;
    },
  },
});
