import React, { useEffect, useState } from "react";
import timeConverter from "./timeConverter";
import './style.css'

interface QuizTimerProps {
  countdownTime: number;
  setTimeTaken: any;
  handleSubmit: () => Promise<void>;
}

const QuizTimer = ({ countdownTime, setTimeTaken, handleSubmit }: QuizTimerProps) => {
  const durationInSeconds = (countdownTime * 60 + 0) * 1000;
  const [timerTime, setTimerTime] = useState<number>(durationInSeconds);
  
  useEffect(() => {
    const timer = setInterval(() => {
      const newTime = timerTime - 1000;

      if (newTime >= 0) {
        setTimerTime(newTime);
      } else {
        clearInterval(timer);
        handleSubmit()
      }
    }, 1000);

    return () => {
      clearInterval(timer);
      setTimeTaken(durationInSeconds - timerTime + 1000);
    };

    // eslint-disable-next-line
  }, [timerTime]);
  const timeResult = timeConverter(timerTime);

  return (
    <div className="flex flex-wrap gap-4 sm:gap-6 justify-center">

        <div className="text-center timer-container">
            <p className="text-3xl px-1 py-1">{timeResult?.hours}</p>
            <hr/>
            <p className="px-1 py-1">hours</p>
        </div>
        <div className="text-center timer-container">
            <p className="text-3xl px-1 py-1">{timeResult?.minutes}</p>
            <hr/>
            <p className="px-1 py-1">minutes</p>
        </div>
        <div className="text-center timer-container">
            <p className="text-3xl px-1 py-1">{timeResult?.seconds}</p>
            <hr/>
            <p className="px-1 py-1">seconds</p>
        </div>
        
    </div>
  );
};

export default QuizTimer;