import { LessonDescription } from "@/models/courseDetails";
import Link from "next/link";
import React from "react";

type VideoAdditionalInputProps = {
  lesson: LessonDescription;
  currentCourse?: string;
  isAuthCourse: boolean;
  courseType: string;
};

const VideoAdditional = (props: VideoAdditionalInputProps) => {
  return (
    <div className="border-general flex justify-between border-b border-t py-2">
      <div className="flex-none">
        <div className="flex space-x-2">
          <svg
            stroke="currentColor"
            fill="currentColor"
            strokeWidth="0"
            viewBox="0 0 24 24"
            className="h-4 w-4 text-orange-600 dark:text-yellow-500"
            height="1em"
            width="1em"
            xmlns="http://www.w3.org/2000/svg"
          >
            <path d="M12 22c5.421 0 10-4.579 10-10S17.421 2 12 2 2 6.579 2 12s4.579 10 10 10zm0-18c4.337 0 8 3.663 8 8s-3.663 8-8 8-8-3.663-8-8 3.663-8 8-8z"></path>
            <path d="M12 17c.901 0 2.581-.168 3.707-1.292l-1.414-1.416C13.85 14.735 12.992 15 12 15c-1.626 0-3-1.374-3-3s1.374-3 3-3c.993 0 1.851.265 2.293.707l1.414-1.414C14.582 7.168 12.901 7 12 7c-2.757 0-5 2.243-5 5s2.243 5 5 5z"></path>
          </svg>
          <span className="cursor-pointer text-xs text-orange-600 dark:text-yellow-500">
            কপিরাইট
          </span>
        </div>
      </div>

      <div className="flex-none">
        {props?.courseType !== "MODEL_TEST" && (
          <div className="flex space-x-2">
            {props?.lesson?.assignments?.length > 0 ? (
              <Link
                href={
                  props.isAuthCourse
                    ? `/${props.currentCourse}/course/${props?.lesson?.id}/assignment`
                    : `/${props.currentCourse}/enrollment`
                }
                className="cursor-pointer text-xs text-green-700 dark:text-green-700"
              >
                এসাইনমেন্ট
              </Link>
            ) : (
              <>
                <svg
                  stroke="currentColor"
                  fill="currentColor"
                  strokeWidth="0"
                  viewBox="0 0 1024 1024"
                  className="h-4 w-4 text-red-600 dark:text-red-500"
                  height="1em"
                  width="1em"
                  xmlns="http://www.w3.org/2000/svg"
                >
                  <path d="M512 64C264.6 64 64 264.6 64 512s200.6 448 448 448 448-200.6 448-448S759.4 64 512 64zm0 820c-205.4 0-372-166.6-372-372 0-89 31.3-170.8 83.5-234.8l523.3 523.3C682.8 852.7 601 884 512 884zm288.5-137.2L277.2 223.5C341.2 171.3 423 140 512 140c205.4 0 372 166.6 372 372 0 89-31.3 170.8-83.5 234.8z"></path>
                </svg>
                <button
                  disabled
                  className="cursor-pointer text-xs text-red-700 dark:text-rose-500"
                >
                  এসাইনমেন্ট নেই
                </button>
              </>
            )}
          </div>
        )}
      </div>
      <div className="flex-none justify-end">
        <div className="flex space-x-2">
          {props?.lesson?.questions && props?.lesson?.questions?.length > 0 ? (
            <div className="relative group/item">
              <Link
                href={
                  props.isAuthCourse
                    ? `/${props.currentCourse}/course/${props?.lesson?.id}/quiz`
                    : `/${props.currentCourse}/enrollment`
                }
                className="group text-xs text-green-700 dark:text-green-700"
              >
                কুইজ
              </Link>
              <div
                className={
                  "opacity-100 translate-y-0 transition ease-out duration-200 absolute z-10 -ml-4 transform w-56 max-w-md lg:ml-0 lg:left-1/2 lg:-translate-x-1/2 group/edit invisible group-hover/item:visible top-full right-0 px-4 bg-white dark:bg-gray-900 shadow"
                }
              >
                <div className="rounded-lg overflow-hidden p-2">
                  <div className="relative grid gap-1 bg-white dark:bg-gray-900 ">
                    <p className="text-xs">কুইজ সময় {props.lesson.duration}</p>
                    <p className="text-xs">
                      মোট প্রশ্ন {props.lesson.questions.length}
                    </p>
                    <p className="text-xs">
                      পাস মার্ক {props.lesson.passingMarks}
                    </p>
                    <p className="text-gray-600 text-xs italic">
                      সময় শেষ হবার পর অটো সাবমিট হয়ে যাবে
                    </p>
                    <Link
                      href={
                        props.isAuthCourse
                          ? `/${props.currentCourse}/course/${props?.lesson?.id}/quiz`
                          : `/${props.currentCourse}/enrollment`
                      }
                      className="p-1 w-20 bg-[#1971C2] text-white flex items-start rounded-lg hover:bg-gray-500"
                    >
                      <p className="text-sm font-medium">শুরু করুন</p>
                    </Link>
                  </div>
                </div>
              </div>
            </div>
          ) : (
            <>
              {" "}
              <svg
                stroke="currentColor"
                fill="currentColor"
                strokeWidth="0"
                viewBox="0 0 1024 1024"
                className="h-4 w-4 text-red-600 dark:text-red-500"
                height="1em"
                width="1em"
                xmlns="http://www.w3.org/2000/svg"
              >
                <path d="M512 64C264.6 64 64 264.6 64 512s200.6 448 448 448 448-200.6 448-448S759.4 64 512 64zm0 820c-205.4 0-372-166.6-372-372 0-89 31.3-170.8 83.5-234.8l523.3 523.3C682.8 852.7 601 884 512 884zm288.5-137.2L277.2 223.5C341.2 171.3 423 140 512 140c205.4 0 372 166.6 372 372 0 89-31.3 170.8-83.5 234.8z"></path>
              </svg>
              <span className="text-xs text-red-700 dark:text-rose-500">
                কুইজ নেই
              </span>
            </>
          )}
        </div>
      </div>
    </div>
  );
};

export default VideoAdditional;
