import { Sections } from "@/models/courseDetails";
import { getAllLessons, getPreviousAndNextLessons } from "@/utils/helper";
import Link from "next/link";
import React from "react";

type VideoControllersInputProps = {
  handleClickFullscreen: () => void;
  cinemaMood: boolean;
  setCinemaMood: React.Dispatch<React.SetStateAction<boolean>>;
  videos: Sections[];
  currentLesson?: string;
  currentCourse?: string;
};

const VideoControllers = (props: VideoControllersInputProps) => {
  const allLessons = getAllLessons(props.videos);
  const { previousLesson, nextLesson } = getPreviousAndNextLessons(
    allLessons,
    props.currentLesson
  );
  
  return (
    <div className="mantine-Group-root mantine-19jxmdp">
      <Link
        className={`mantine-Button-filled bg-slate-900 dark:bg-secondary2 hover:bg-slate-700 dark:hover:bg-secondary1 text-white mantine-Button-root mantine-Group-child mantine-1kinyd3 ${
          (!previousLesson || !previousLesson.isAuthUser) &&
          "pointer-events-none !bg-gray-500"
        }`}
        href={`/${props.currentCourse}/course/${previousLesson?.id}`}
      >
        <div className="mantine-3xbgk5 mantine-Button-inner">
          <span className="mantine-Button-icon mantine-Button-leftIcon mantine-1g4orza">
            <svg
              stroke="currentColor"
              fill="currentColor"
              strokeWidth="0"
              viewBox="0 0 1024 1024"
              className="h-3 w-3"
              height="1em"
              width="1em"
              xmlns="http://www.w3.org/2000/svg"
            >
              <path d="M872 474H286.9l350.2-304c5.6-4.9 2.2-14-5.2-14h-88.5c-3.9 0-7.6 1.4-10.5 3.9L155 487.8a31.96 31.96 0 0 0 0 48.3L535.1 866c1.5 1.3 3.3 2 5.2 2h91.5c7.4 0 10.8-9.2 5.2-14L286.9 550H872c4.4 0 8-3.6 8-8v-60c0-4.4-3.6-8-8-8z"></path>
            </svg>
          </span>
          <span className="mantine-qo1k2 mantine-Button-label">আগের লেসন</span>
        </div>
      </Link>
      <div className="mantine-gnzaph mantine-Group-child flex items-center gap-4">
        <button
          className="mantine-Button-light hidden lg:block mantine-Button-root mantine-zjmy !bg-[#1971C2] !text-white"
          type="button"
          onClick={props.handleClickFullscreen}
        >
          <div className="mantine-3xbgk5 mantine-Button-inner ">
            <span className="mr-0 mantine-Button-icon mantine-Button-leftIcon mantine-1g4orza">
              <svg height="48px" version="1.1" viewBox="0 0 36 36" width="44px">
                <path
                  d="m 26,13 0,10 -16,0 0,-10 z m -14,2 12,0 0,6 -12,0 0,-6 z"
                  fill="#a5d8ff"
                  fillRule="evenodd"
                  id="ytp-id-144"
                ></path>
              </svg>
            </span>
            <span className="mantine-qo1k2 mantine-Button-label">বড় করুন</span>
          </div>
        </button>
        <button
          className="mantine-Button-light hidden lg:block mantine-Button-root mantine-zjmy !bg-[#1971C2] !text-white"
          type="button"
          onClick={() => props.setCinemaMood(!props.cinemaMood)}
        >
          <div className="mantine-3xbgk5 mantine-Button-inner">
            <span className="mr-0 mantine-Button-icon mantine-Button-leftIcon mantine-1g4orza">
              <svg height="48px" version="1.1" viewBox="0 0 36 36" width="44px">
                <path
                  d="m 26,13 0,10 -16,0 0,-10 z m -14,2 12,0 0,6 -12,0 0,-6 z"
                  fill="#a5d8ff"
                  fillRule="evenodd"
                  id="ytp-id-144"
                ></path>
              </svg>
            </span>
            <span className="mantine-qo1k2 mantine-Button-label">
              ছিনেমা মোড
            </span>
          </div>
        </button>
        <Link
          className={`mantine-Button-filled bg-slate-900 dark:bg-secondary2 hover:bg-slate-700 dark:hover:bg-secondary1 text-white mantine-Button-root mantine-1gr65gc ${
            (!nextLesson || !nextLesson?.isAuthUser) &&
            "pointer-events-none !bg-gray-500"
          }`}
          href={`/${props.currentCourse}/course/${nextLesson?.id}`}
        >
          <div className="mantine-3xbgk5 mantine-Button-inner">
            <span className="mantine-qo1k2 mantine-Button-label">
              পরের লেসন
            </span>
            <span className="mantine-Button-icon mantine-Button-rightIcon mantine-386jen">
              <svg
                stroke="currentColor"
                fill="currentColor"
                strokeWidth="0"
                viewBox="0 0 1024 1024"
                className="h-3 w-3"
                height="1em"
                width="1em"
                xmlns="http://www.w3.org/2000/svg"
              >
                <path d="M869 487.8L491.2 159.9c-2.9-2.5-6.6-3.9-10.5-3.9h-88.5c-7.4 0-10.8 9.2-5.2 14l350.2 304H152c-4.4 0-8 3.6-8 8v60c0 4.4 3.6 8 8 8h585.1L386.9 854c-5.6 4.9-2.2 14 5.2 14h91.5c1.9 0 3.8-.7 5.2-2L869 536.2a32.07 32.07 0 0 0 0-48.4z"></path>
              </svg>
            </span>
          </div>
        </Link>
      </div>
    </div>
  );
};

export default VideoControllers;
