'use client'

import React, { useState } from "react";
import Rating from "./Rating";
import clientAxios from "@/services/config";
import { COURSE_API } from "@/services/api-end-point/courses";
import { CourseVideoProps } from "@/models/home";
import { SessionProps } from "@/actions/user-info";
import { ToastContainer, toast } from "react-toastify";

type CourseTypes = {
  course: CourseVideoProps;
  session: SessionProps;
};


const CourseFeedback = ({ course, session }: CourseTypes) => {
  const [ratingValue, setRatingValue] = useState(0);
  const [details, setDetails] = useState("");

  const handleRatingAction = (value: any) => {
    setRatingValue(value);
  };
  const handleSubmit = (e: React.SyntheticEvent<HTMLFormElement>) => {
    e.preventDefault();
    clientAxios.post(COURSE_API.create_feedback, {
      feedbackText: details,
      courseId: course._id,
      courseName: course.name,
      userId: session.user?.id,
      username: session.user?.name,
      rate: ratingValue,
    }).then(_ => {
      setDetails("")
      setRatingValue(0)
      toast.success('Feedback submitted successfully')
    }).catch(err => toast.error(err.message))
  };
  return (
    <div className="max-w-[85rem] px-4 py-10 sm:px-6 lg:px-8 lg:py-14 mx-auto">
      <ToastContainer />
      <div className="grid md:grid-cols-2 items-center gap-12">
        <div>
          <h1 className="text-3xl font-bold text-gray-800 dark:text-white sm:text-4xl lg:text-5xl lg:leading-tight">
            Feedback This Course
          </h1>
          <p className="mt-1 md:text-lg text-gray-800 dark:text-white">
            We help brands and platforms turn big ideas into beautiful digital
            products and experiences.
          </p>

          <div className="mt-8">
            <h2 className="text-lg font-semibold text-gray-800 dark:text-white">
              What can I expect?
            </h2>

            <ul className="mt-2 space-y-2">
              <li className="flex space-x-3">
                <svg
                  className="flex-shrink-0 mt-0.5 size-5 text-gray-600 dark:text-white"
                  xmlns="http://www.w3.org/2000/svg"
                  width="24"
                  height="24"
                  viewBox="0 0 24 24"
                  fill="none"
                  stroke="currentColor"
                  stroke-width="2"
                  stroke-linecap="round"
                  stroke-linejoin="round"
                >
                  <polyline points="20 6 9 17 4 12" />
                </svg>
                <span className="text-gray-600 dark:text-white">
                  How would you rate your overall experience with the course?
                </span>
              </li>

              <li className="flex space-x-3">
                <svg
                  className="flex-shrink-0 mt-0.5 size-5 text-gray-600 dark:text-white"
                  xmlns="http://www.w3.org/2000/svg"
                  width="24"
                  height="24"
                  viewBox="0 0 24 24"
                  fill="none"
                  stroke="currentColor"
                  stroke-width="2"
                  stroke-linecap="round"
                  stroke-linejoin="round"
                >
                  <polyline points="20 6 9 17 4 12" />
                </svg>
                <span className="text-gray-600 dark:text-white">
                  Was the course material comprehensive and well-organized?
                </span>
              </li>

              <li className="flex space-x-3">
                <svg
                  className="flex-shrink-0 mt-0.5 size-5 text-gray-600 dark:text-white"
                  xmlns="http://www.w3.org/2000/svg"
                  width="24"
                  height="24"
                  viewBox="0 0 24 24"
                  fill="none"
                  stroke="currentColor"
                  stroke-width="2"
                  stroke-linecap="round"
                  stroke-linejoin="round"
                >
                  <polyline points="20 6 9 17 4 12" />
                </svg>
                <span className="text-gray-600 dark:text-white">
                  How relevant was the course content to your needs?
                </span>
              </li>
              <li className="flex space-x-3">
                <svg
                  className="flex-shrink-0 mt-0.5 size-5 text-gray-600 dark:text-white"
                  xmlns="http://www.w3.org/2000/svg"
                  width="24"
                  height="24"
                  viewBox="0 0 24 24"
                  fill="none"
                  stroke="currentColor"
                  stroke-width="2"
                  stroke-linecap="round"
                  stroke-linejoin="round"
                >
                  <polyline points="20 6 9 17 4 12" />
                </svg>
                <span className="text-gray-600 dark:text-white">
                  Were the learning objectives clearly defined and met?
                </span>
              </li>
              <li className="flex space-x-3">
                <svg
                  className="flex-shrink-0 mt-0.5 size-5 text-gray-600 dark:text-white"
                  xmlns="http://www.w3.org/2000/svg"
                  width="24"
                  height="24"
                  viewBox="0 0 24 24"
                  fill="none"
                  stroke="currentColor"
                  stroke-width="2"
                  stroke-linecap="round"
                  stroke-linejoin="round"
                >
                  <polyline points="20 6 9 17 4 12" />
                </svg>
                <span className="text-gray-600 dark:text-white">
                  Do you feel more confident in the subject after completing the
                  course?
                </span>
              </li>
            </ul>
          </div>
        </div>

        <div className="relative">
          <div className="flex flex-col border rounded-xl p-4 sm:p-6 lg:p-10">
            <h2 className="text-xl font-semibold text-gray-800 dark:text-white">
              Fill in the form
            </h2>

            <form onSubmit={handleSubmit}>
              <div className="mt-6 grid gap-4 lg:gap-6">
                <Rating
                  iconSize="l"
                  showOutOf={true}
                  enableUserInteraction={true}
                  onClick={handleRatingAction}
                />
                <div>
                  <label
                    htmlFor="hs-about-hire-us-1"
                    className="block mb-2 text-sm text-gray-700 dark:text-white font-medium"
                  >
                    Details
                  </label>
                  <textarea
                    value={details}
                    onChange={(e) => setDetails(e.target.value)}
                    id="hs-about-hire-us-1"
                    name="hs-about-hire-us-1"
                    rows={4}
                    className="py-3 px-4 block w-full border dark:border-gray-200 border-black rounded-lg text-sm focus:border-blue-500 focus:ring-blue-500 disabled:opacity-50 disabled:pointer-events-none"
                  ></textarea>
                </div>
              </div>

              <div className="mt-6 grid">
                <button
                  type="submit"
                  className="w-full py-3 px-4 inline-flex justify-center items-center gap-x-2 text-sm font-semibold rounded-lg border border-transparent bg-blue-600 text-white hover:bg-blue-700 disabled:opacity-50 disabled:pointer-events-none"
                >
                  Submit
                </button>
              </div>
            </form>

            <div className="mt-3 text-center">
              <p className="text-sm text-gray-500 dark:text-white">
                {" We'll get back to you in 1-2 business days."}
              </p>
            </div>
          </div>
        </div>
      </div>
    </div>
  );
};

export default CourseFeedback;
