/* eslint-disable @next/next/no-img-element */

import { CourseInstructorProps } from "@/models/home";
import { USER_PROFILE } from "@/utils/helper";
import Image from "next/image";

type CourseInstructorTypes = {
  instructor: CourseInstructorProps[];
};

const CourseInstructor = ({ instructor }: CourseInstructorTypes) => {
  return (
    <section
      className="wrapper dark:!bg-slate-900 dark:bg-none"
      style={{
        backgroundImage: `url(https://tailwindcss.com/_next/static/media/hero@75.b2469a49.jpg)`,
        backgroundSize: "150rem",
        backgroundBlendMode: "overlay",
      }}
    >
      <div
        style={{
          backgroundImage: `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 32 32' width='32' height='32' fill='none' stroke='rgb(15 23 42 / 0.04)'%3e%3cpath d='M0 .5H31.5V32'/%3e%3c/svg%3e")`,
        }}
      >
        <div className="container space-y-8">
          <h1 className="section-title text-center text-slate-100 dark:text-gray-200">
            কোর্স ইন্সট্রাক্টর
          </h1>
          <div className="flex gap-8 flex-wrap justify-center">
            {instructor?.map((item: CourseInstructorProps) => {
              const instructorInfo =
                typeof item?.info === "string"
                  ? JSON.parse(item?.info)
                  : item?.info;
              return (
                <div className="justify-center" key={item?.id}>
                  <div
                    className="transform  rounded-xl h-full sm:h-64 sm:w-100 bg-white shadow-xl transition duration-300 hover:scale-105"
                    style={{ minWidth: 250 }}
                  >
                    <div className="flex flex-col items-center pb-10 p-4">
                      <img
                        className="w-24 h-24 mb-3 rounded-full shadow-lg mt-2"
                        src={item?.image || USER_PROFILE}
                        alt="Bonnie image"
                      />
                      <h5 className="mb-1 text-xl font-medium text-gray-900 dark:text-gray-900">
                        {item?.name}
                      </h5>
                      <span className="text-sm text-gray-500 dark:text-gray-400">
                        {instructorInfo?.degree || ""}
                      </span>
                      {instructorInfo?.socialLink && (
                        <div className="flex mt-4 md:mt-6">
                          <a
                            href={instructorInfo?.socialLink || ""}
                            className="py-2 px-4 ms-2 text-sm font-medium text-gray-900 focus:outline-none bg-white rounded-lg border border-gray-200 hover:bg-gray-100 hover:text-blue-700 focus:z-10 focus:ring-4 focus:ring-gray-100 dark:focus:ring-gray-700 dark:bg-gray-800 dark:text-gray-400 dark:border-gray-600 dark:hover:text-white dark:hover:bg-gray-700"
                          >
                            বিস্তারিত দেখুন
                          </a>
                        </div>
                      )}
                    </div>
                  </div>
                </div>
              );
            })}
          </div>
        </div>
      </div>
    </section>
  );
};

export default CourseInstructor;
