import { CourseRoutineProps } from "@/models/home";
import React from "react";

interface RoutineProps {
  title: string;
  remarks: string;
  dateTime: string;
}

type CourseRoutineTypes = {
  routine: CourseRoutineProps;
};

const CurseRoutine = (props: CourseRoutineTypes) => {
  const { routine } = props;
  const parsedRoutine =
    typeof routine?.routines === "string"
      ? JSON.parse(routine?.routines)
      : routine?.routines;

  return (
    <section className="mx-auto font-mono">
      <div className="w-full mb-8 overflow-hidden rounded-lg shadow-lg">
        <h1 className="text-lg font-bold p-2 text-center">{`রুটিন  ${routine?.name}`}</h1>
        <div className="w-full overflow-x-auto">
          <table className="w-full">
            <thead>
              <tr className="text-md font-semibold tracking-wide text-left text-gray-900 bg-gray-100 uppercase border-b border-gray-600 w-100">
                <th className="px-4 py-3 w-1/4">Title</th>
                <th className="px-4 py-3 w-1/2">Remarks</th>
                <th className="px-4 py-3 w-1/4">Date</th>
              </tr>
            </thead>
            <tbody className="bg-white">
              {parsedRoutine?.map((routine: RoutineProps, index: number) => {
                return (
                  <tr className="text-gray-700 w-100" key={index}>
                    <td className="p-1 border w-25">
                      <div className="flex items-center text-sm">
                        <p className="font-semibold text-black">
                          {routine?.title}
                        </p>
                      </div>
                    </td>
                    <td className="p-1 text-xs border w-50">
                      {routine?.remarks}
                    </td>
                    <td className="p-1 text-sm border w-25">
                      {routine?.dateTime}
                    </td>
                  </tr>
                );
              })}
            </tbody>
          </table>
        </div>
      </div>
    </section>
  );
};

export default CurseRoutine;
