"use client";
import { useState } from "react";

const FAQComponent = ({ faqQuestion }: any) => {
  const [showAll, setShowAll] = useState(false);
  const numberOfFAQsToShow = showAll ? faqQuestion.length : 4;

  return (
    <div className="m-5 bg-gray-300 pb-2 md:mb-12 md:bg-white md:py-0 dark:bg-gray-800">
      {faqQuestion?.length > 0 && (
        <div className="bg-white dark:bg-gray-800 pb-1 md:pb-0">
          <div className="mb-0">
            <h1 className="section-title dark:text-white text-center p-2">
              সচরাচর <span className="text-[#07A8ED]">জিজ্ঞাসা</span>
            </h1>
            <div className="relative mb-20">
              <div className="rounded-md md:border md:px-5">
                {faqQuestion
                  .slice(0, numberOfFAQsToShow)
                  .map((faq: any, index: number) => (
                    <details
                      key={index + 1}
                      className="flex border-b border-dashed last:border-0 hover:bg-gray-100 dark:hover:bg-gray-700"
                    >
                      <summary className="cursor-pointer py-4 font-medium flex items-center justify-between">
                        <h3 className="text-sm font-semibold md:text-base">
                          {faq.question}
                        </h3>
                        <svg
                          className="w-4 h-4 fill-current text-gray-500"
                          xmlns="http://www.w3.org/2000/svg"
                          viewBox="0 0 24 24"
                          strokeWidth="2"
                          strokeLinecap="round"
                          strokeLinejoin="round"
                        >
                          <polyline points="18 15 12 9 6 15" />
                        </svg>
                      </summary>
                      <div className="pb-4">
                        <div>
                          <p>- {faq.answer}</p>
                        </div>
                      </div>
                    </details>
                  ))}
              </div>
              {!showAll ? (
                <button
                  className="absolute bottom-[-15px] left-1/2 flex translate-x-[-50%] items-center gap-2 rounded-full bg-white px-4 py-1 text-sm text-gray-500 shadow-[0px_0px_17.0361px_#E7EAF7] hover:bg-gray-50 hover:text-gray-700"
                  onClick={() => setShowAll(true)}
                >
                  বেশি দেখুন
                  <svg
                    stroke="currentColor"
                    fill="none"
                    strokeWidth="2"
                    viewBox="0 0 24 24"
                    strokeLinecap="round"
                    strokeLinejoin="round"
                    height="18"
                    width="18"
                    xmlns="http://www.w3.org/2000/svg"
                  >
                    <polyline points="18 15 12 9 6 15" />
                  </svg>
                </button>
              ) : (
                <button
                  className="absolute bottom-[-15px] left-1/2 flex translate-x-[-50%] items-center gap-2 rounded-full bg-white px-4 py-1 text-sm text-gray-500 shadow-[0px_0px_17.0361px_#E7EAF7] hover:bg-gray-50 hover:text-gray-700"
                  onClick={() => setShowAll(false)}
                >
                  কম দেখুন
                  <svg
                    stroke="currentColor"
                    fill="none"
                    strokeWidth="2"
                    viewBox="0 0 24 24"
                    strokeLinecap="round"
                    strokeLinejoin="round"
                    height="18"
                    width="18"
                    xmlns="http://www.w3.org/2000/svg"
                  >
                    <polyline points="18 15 12 9 6 15" />
                  </svg>
                </button>
              )}
            </div>
          </div>
        </div>
      )}
    </div>
  );
};

export default FAQComponent;
