/* eslint-disable @next/next/no-img-element */
import { CourseVideoProps } from '@/models/home';
import Image from 'next/image';
import Link from 'next/link';
import React from 'react'

type CardItemsProps = {
  course: CourseVideoProps;
};

const CardItems = (props: CardItemsProps) => {
  return (
    <Link href={`/${props.course._id}`}>
      <div className="my-0 mb-4 h-full w-full cursor-pointer gap-4 rounded-none border-b border-[#E5E7EB] pb-4 transition-colors duration-200 sm:max-w-[200px] sm:flex-col sm:rounded sm:border sm:pb-0 md:min-w-[272px] md:hover:border-green xs:border-dashed">
        <div className="transition-opacity duration-300 ease-in-out">
          <Image
            alt="HSC অনলাইন ব্যাচ"
            height={300}
            width={250}
            style={{ height: '240px', margin: 'auto' }}
            src={props.course.thumbnail || "https://arafatacczone.com/wp-content/uploads/2023/12/406464339_2143208502690764_259578852390532379_n.jpg"}
          />
        </div>
        <div className=" min-w-0 flex-1 flex-col justify-between rounded-bl-[4px] rounded-br-[4px] p-0 sm:p-[14px]">
          <div className='p-1'>
            <h2 className="mb-1 text-sm font-semibold line-clamp-2 md:text-lg text-center">
              {props.course.name}
            </h2>
          </div>
          <div className="flex items-center justify-around">
            {
              props?.course?.isFree ?
                <div
                  className="relative grid select-none items-center whitespace-nowrap rounded-lg bg-green-500 py-1.5 px-3 font-sans text-xs font-bold uppercase text-white">
                  <span className="">{"Free"}</span>
                </div> :
                props?.course?.isDiscount ?
                  <>
                    <div
                      className="line-through relative grid select-none items-center whitespace-nowrap rounded-lg bg-blue-500 py-1.5 px-3 font-sans text-xs font-bold uppercase text-white">
                      <span style={{ textDecoration: 'line-through' }}>{props?.course.price} টাকা</span>
                    </div>
                    <div
                      className="relative grid select-none items-center whitespace-nowrap rounded-lg bg-indigo-500 py-1.5 px-3 font-sans text-xs font-bold uppercase text-white">
                      <span className="">{Math.ceil(props?.course?.price - (props?.course?.price * props?.course?.discount) / 100)} টাকা</span>
                    </div>
                  </> :
                  <div
                    className="relative grid select-none items-center whitespace-nowrap rounded-lg bg-indigo-500 py-1.5 px-3 font-sans text-xs font-bold uppercase text-white">
                    <span className="">{props?.course.price} টাকা</span>
                  </div>
            }
          </div>
        </div>
      </div>
    </Link>
  );
}

export default CardItems