"use client";
import Image from "next/image";
import Link from "next/link";
import React, { RefObject } from "react";
import { useRef } from "react";
import { useState } from "react";

const CourseSlider = (props: any) => {
  const { courses } = props;
  const [isMoved, setIsMoved] = useState(false);
  const rowRef: RefObject<HTMLDivElement> = useRef(null);
  const handleClick = (direction: any) => {
    setIsMoved(true);
    if (rowRef.current) {
      const { scrollLeft, clientWidth } = rowRef.current;

      const scrollTo =
        direction === "left"
          ? scrollLeft - clientWidth
          : scrollLeft + clientWidth;
      rowRef.current.scrollTo({ left: scrollTo, behavior: "smooth" });
    }
  };
  return (
    <div className="all_category relative overflow-hidden group/item m-auto container">
      <div className="flex justify-center">
        <div className="p-3 border-4 border-dashed border-violet-300 inline-block">
          <h1 className="font-bold text-2xl text-center text-black dark:text-white">
            {props.title}
          </h1>
        </div>
      </div>
      <div
        className="flex items-center space-x-2 overflow-x-scroll scrollbar-hide md:space-x-4 py-2"
        ref={rowRef}
      >
        {courses?.map((item: any) => (
          <div
            className="overflow-hidden rounded-lg shadow-lg hover:shadow-xl transition duration-300 border dark:border-2-white hover:scale-105 cursor-pointer min-w-[200px] md:min-w-[320px]"
            key={item._id}
            style={{ minWidth: "320px", minHeight: "400px", maxWidth: "320px" }}
          >
            <Link href={`/${item._id}`} className="flex-shrink-0">
              <Image
                className="mx-auto w-[300px] h-[300px] rounded-md object-cover"
                src={
                  item.thumbnail ||
                  "https://arafatacczone.com/wp-content/uploads/2023/12/406464339_2143208502690764_259578852390532379_n.jpg"
                }
                alt=""
                width={250}
                height={250}
                sizes="100vw"
              />
            </Link>
            <div className="flex flex-1 flex-col justify-between bg-white p-6 dark:bg-gray-800">
              <p className="lg:h-[46px] sm:h-10 h-8 px-2 text-black lg:text-base sm:text-sm line-clamp-2 text-center font-bold text-xl dark:text-white">
                {item.name}
              </p>
              <div className="mt-6 flex flex-wrap md:flex-nowrap justify-between gap-4 lg:mx-0 lg:flex-row">
                {item?.isFree ? (
                  <div className="relative grid select-none items-center whitespace-nowrap rounded-lg bg-green-500 py-1.5 px-3 font-sans text-xs font-bold uppercase text-white">
                    <span className="">{"Free"}</span>
                  </div>
                ) : item?.isDiscount ? (
                  <>
                    <div className="line-through relative grid select-none items-center whitespace-nowrap rounded-lg bg-blue-500 py-1.5 px-1 md:px-3 font-sans text-xs font-bold uppercase text-white">
                      <span style={{ textDecoration: "line-through" }}>
                        {item.price} টাকা
                      </span>
                    </div>
                    <div className="relative grid select-none items-center whitespace-nowrap rounded-lg bg-indigo-500 py-1.5 px-1 md:px-3 font-sans text-xs font-bold uppercase text-white">
                      <span className="">
                        {item.price - (item?.discount || 0)}{" "}
                        টাকা
                      </span>
                    </div>
                  </>
                ) : (
                  <div className="relative grid select-none items-center whitespace-nowrap rounded-lg bg-indigo-500 py-1.5 px-1 md:px-3 font-sans text-xs font-bold uppercase text-white">
                    <span className="">{item.price} টাকা</span>
                  </div>
                )}
                <div className="flex justify-center items-center">
                  <div className="relative inline-flex group">
                    <div className="absolute transitiona-all duration-1000 opacity-70 -inset-px bg-gradient-to-r from-[#44BCFF] via-[#FF44EC] to-[#FF675E] rounded-xl blur-lg group-hover:opacity-100 group-hover:-inset-1 group-hover:duration-200 animate-tilt"></div>
                    <Link
                      href={`/${item._id}`}
                      title=""
                      className="p-1 relative inline-flex items-center justify-center px-2 py-2 text-xs md:text-md font-bold text-white transition-all duration-200 bg-gray-900 font-pj rounded-xl focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-gray-900"
                      role="button"
                    >
                      বিস্তারিত
                    </Link>
                  </div>
                </div>
              </div>
              <div className="mt-3 flex w-full justify-center">
                <div className="text-2 flex space-x-1 text-sm">
                  <svg
                    stroke="currentColor"
                    fill="currentColor"
                    strokeWidth="0"
                    viewBox="0 0 1024 1024"
                    className="mr-0 flex-shrink-0 lg:mr-1"
                    height="16"
                    width="16"
                    xmlns="http://www.w3.org/2000/svg"
                  >
                    <path d="M512 64C264.6 64 64 264.6 64 512s200.6 448 448 448 448-200.6 448-448S759.4 64 512 64zm0 820c-205.4 0-372-166.6-372-372s166.6-372 372-372 372 166.6 372 372-166.6 372-372 372z"></path>
                    <path d="M464 336a48 48 0 1 0 96 0 48 48 0 1 0-96 0zm72 112h-48c-4.4 0-8 3.6-8 8v272c0 4.4 3.6 8 8 8h48c4.4 0 8-3.6 8-8V456c0-4.4-3.6-8-8-8z"></path>
                  </svg>
                  <span className="text-center text-xs md:text-sm">
                    এনরোলমেন্টের সময় বাংলাদেশি মোবাইল নাম্বার ব্যবহার করুন
                  </span>
                </div>
              </div>
            </div>
          </div>
        ))}
      </div>
      <div
        className={`allCate-button-prev absolute top-1/2 -left-16 -translate-y-1/2 w-8 h-8 flex justify-center items-center bg-white rounded-full drop-shadow-bmp z-50 transition-all ease-out group-hover/item:left-3 ${
          !isMoved && "hidden"
        } cursor-pointer group/edit`}
        onClick={() => handleClick("left")}
      >
        <svg
          xmlns="http://www.w3.org/2000/svg"
          className="h-5 w-5 text-[#0DC1D9]"
          fill="none"
          viewBox="0 0 24 24"
          stroke="currentColor"
          strokeWidth="2"
        >
          <path
            strokeLinecap="round"
            strokeLinejoin="round"
            d="M15 19l-7-7 7-7"
          />
        </svg>
      </div>
      <div
        onClick={() => handleClick("right")}
        className="allCate-button-next absolute top-1/2 -right-8 -translate-y-1/2 w-8 h-8 flex justify-center items-center bg-white rounded-full drop-shadow-bmp z-50 group-hover/item:right-3 transition-all ease-in-out cursor-pointer"
      >
        <svg
          xmlns="http://www.w3.org/2000/svg"
          className="h-5 w-5 text-[#0DC1D9]"
          fill="none"
          viewBox="0 0 24 24"
          stroke="currentColor"
          strokeWidth="2"
        >
          <path strokeLinecap="round" strokeLinejoin="round" d="M9 5l7 7-7 7" />
        </svg>
      </div>
    </div>
  );
};

export default CourseSlider;
