import React from 'react';

const CarouselItem = ({ href, imgSrc, title, instructor } : any) => {
    return (
        <a href={href}>
            <div className="bg-[#121220] my-0 flex h-full min-w-[200px] max-w-[200px] cursor-pointer flex-col overflow-hidden rounded transition-colors hover:border-green md:min-w-[272px] md:rounded-[6px]">
                <div className="undefined opacity-0 transition-opacity duration-300 ease-in-out" style={{ fontSize: '0px', opacity: 1 }}>
                    <img
                        alt={title}
                        data-original-src={imgSrc}
                        draggable="false"
                        fetchPriority="high"
                        width="272"
                        height="152"
                        decoding="async"
                        data-nimg="1"
                        className=""
                        src={imgSrc}
                        style={{ color: 'transparent' }}
                    />
                </div>
                <div className="flex min-w-0 flex-1 flex-col justify-between gap-2 p-[14px]">
                    <div>
                        <h2 className="mb-1 h-14 text-sm font-semibold line-clamp-2 md:text-lg text-white">{title}</h2>
                        <h3 className="max-h-[50px] overflow-hidden truncate text-xs text-[#6B7280] md:text-sm">{instructor}</h3>
                    </div>
                    <div>
                        <p className="mt-2 flex gap-1 text-sm text-[#1DAB55]">
                            <span>বিস্তারিত</span>
                            <svg
                                stroke="currentColor"
                                fill="currentColor"
                                strokeWidth="0"
                                viewBox="0 0 16 16"
                                height="20"
                                width="20"
                                xmlns="http://www.w3.org/2000/svg"
                            >
                                <path fillRule="evenodd" d="M4 8a.5.5 0 0 1 .5-.5h5.793L8.146 5.354a.5.5 0 1 1 .708-.708l3 3a.5.5 0 0 1 0 .708l-3 3a.5.5 0 0 1-.708-.708L10.293 8.5H4.5A.5.5 0 0 1 4 8z"></path>
                            </svg>
                        </p>
                    </div>
                </div>
            </div>
        </a>
    );
};

const NextJsComponent = () => {
    return (
        <div className="">
            <div className="tenms-carousel relative dark both">
                {/* Left Arrow */}
                <div className="cursor-pointer absolute left-0 top-1/2 z-[2] block -translate-y-1/2 cursor-pointer xl:left-[-40px] mx-lg:hidden">
                    <svg xmlns="http://www.w3.org/2000/svg" width="33" height="32" fill="none" viewBox="0 0 33 32" className="rotate-180">
                        <path fill="#fff" fillOpacity="0.5" fillRule="evenodd" d="M16.757 32c8.836 0 16-7.163 16-16s-7.164-16-16-16c-8.837 0-16 7.163-16 16s7.163 16 16 16zM15.064 8.893a1 1 0 00-1.415 1.415L19.342 16l-5.693 5.692a1 1 0 001.415 1.415l6.4-6.4a1 1 0 000-1.414l-6.4-6.4z" clipRule="evenodd"></path>
                    </svg>
                </div>

                {/* Carousel Content */}
                <div className="w-full overflow-hidden">
                    <div className="scrollbar-hide relative flex flex-nowrap gap-4 overflow-x-scroll scroll-smooth">
                        {/* Carousel Items */}
                        <CarouselItem href="/product/ielts-live-batch/" imgSrc="https:///cdn.10minuteschool.com/images/thumbnails/best-ielts-live-batch-thumbnail.jpg" title="IELTS LIVE Batch" instructor="Munzereen Shahid +3" />
                        <CarouselItem href="/product/ghore-boshe-spoken-english/" imgSrc="https://cdn.10minuteschool.com/images/thumbnails/skills/ghore-boshe-Spoken-English-course-thumbnail-by-Munzereen-Shahid-16x9.jpg" title="ঘরে বসে Spoken English" instructor="Munzereen Shahid" />
                        <CarouselItem href="/product/ielts-course/" imgSrc="https://cdn.10minuteschool.com/images/thumbnails/IELTS_new_16_9.png" title="IELTS Course by Munzereen Shahid" instructor="Munzereen Shahid" />
                        <CarouselItem href="/product/ielts-course/" imgSrc="https://cdn.10minuteschool.com/images/thumbnails/IELTS_new_16_9.png" title="IELTS Course by Munzereen Shahid" instructor="Munzereen Shahid" />
                        {/* Add more CarouselItem components as needed */}
                    </div>
                </div>

                {/* Right Arrow */}
                <div className="cursor-pointer absolute right-0 top-1/2 z-[3] block -translate-y-1/2 cursor-pointer xl:right-[-40px] mx-lg:hidden">
                    <svg xmlns="http://www.w3.org/2000/svg" width="33" height="32" fill="none" viewBox="0 0 33 32">
                        <path fill="#fff" fillOpacity="0.5" fillRule="evenodd" d="M16.757 32c8.836 0 16-7.163 16-16s-7.164-16-16-16c-8.837 0-16 7.163-16 16s7.163 16 16 16zM15.064 8.893a1 1 0 00-1.415 1.415L19.342 16l-5.693 5.692a1 1 0 001.415 1.415l6.4-6.4a1 1 0 000-1.414l-6.4-6.4z" clipRule="evenodd"></path>
                    </svg>
                </div>
            </div>
            {/* End of tenms-carousel */}

            {/* Button to View All Courses */}
            <div className="flex justify-center mt-2 md:mt-6 md:pt-12">
                <a className="bg-[#1CAB55] group hover:bg-[#198b46] transition-colors duration-300 flex gap-2 justify-center items-center text-white font-medium py-3 pl-7 pr-5 rounded" href="/categories/language-learning/">সকল কোর্স
                    <svg stroke="currentColor" fill="none" strokeWidth="2" viewBox="0 0 24 24" strokeLinecap="round" strokeLinejoin="round" className="transition-transform group-hover:translate-x-1" height="20" width="20" xmlns="http://www.w3.org/2000/svg">
                        <polyline points="9 18 15 12 9 6"></polyline>
                    </svg>
                </a>
            </div>
        </div>
    );
};

export default NextJsComponent;