import React from 'react';
import Image from "next/image";

const TestCourseItems = (props: any) => {
    const { courses } = props;
    return (
        <div className="relative bg-gray-50 pt-4 pb-4 px-2 lg:px-2 lg:pt-8 lg:pb-8 dark:bg-gray-800">
            <div className="relative mx-auto">
                <div className="flex justify-center">
                    <div className="p-3 border-4 border-dashed border-violet-300 inline-block">
                        <h1 className="font-bold text-2xl text-center text-black dark:text-white">{"কোর্স সমূহ"}</h1>
                    </div>
                </div>
                <div className="scroll-view mx-auto mt-12 grid max-w-lg gap-5 lg:max-w-none lg:grid-cols-3" style={{ display: 'flex', overflowX: 'scroll' }}>
                    {
                        courses?.map((item: any) => (
                            <div className="overflow-hidden rounded-lg shadow-lg hover:shadow-xl transition duration-300 border dark:border-2-white" key={item._id} style={{ minWidth: '320px' }}>
                                <div className="flex-shrink-0">
                                    <Image className="h-80 object-cover" src={item.thumbnail || "https://arafatacczone.com/wp-content/uploads/2023/12/406464339_2143208502690764_259578852390532379_n.jpg"} alt="" width={300} height={200} style={{ margin: 'auto' }} />
                                </div>
                                <div className="flex flex-1 flex-col justify-between bg-white p-6 dark:bg-gray-800">
                                    <p className="text-1 bold text-medium mt-4 !text-center lg:text-left">
                                        {item.name}
                                    </p>
                                    <div className="mt-6 flex justify-between gap-4 lg:mx-0 lg:flex-row">
                                        {
                                            item?.isFree ?
                                                <div
                                                    className="relative grid select-none items-center whitespace-nowrap rounded-lg bg-green-500 py-1.5 px-3 font-sans text-xs font-bold uppercase text-white">
                                                    <span className="">{"Free"}</span>
                                                </div> :
                                                item?.isDiscount ?
                                                    <>
                                                        <div
                                                            className="line-through relative grid select-none items-center whitespace-nowrap rounded-lg bg-blue-500 py-1.5 px-3 font-sans text-xs font-bold uppercase text-white">
                                                            <span style={{ textDecoration: 'line-through' }}>{item.price} টাকা</span>
                                                        </div>
                                                        <div
                                                            className="relative grid select-none items-center whitespace-nowrap rounded-lg bg-indigo-500 py-1.5 px-3 font-sans text-xs font-bold uppercase text-white">
                                                            <span className="">{item?.price - (item?.price * item?.discount) / 100} টাকা</span>
                                                        </div>
                                                    </> :
                                                    <div
                                                        className="relative grid select-none items-center whitespace-nowrap rounded-lg bg-indigo-500 py-1.5 px-3 font-sans text-xs font-bold uppercase text-white">
                                                        <span className="">{item.price} টাকা</span>
                                                    </div>
                                        }
                                        <div className="flex justify-center items-center">
                                            <div className="relative inline-flex group">
                                                <div className="absolute transitiona-all duration-1000 opacity-70 -inset-px bg-gradient-to-r from-[#44BCFF] via-[#FF44EC] to-[#FF675E] rounded-xl blur-lg group-hover:opacity-100 group-hover:-inset-1 group-hover:duration-200 animate-tilt"></div>
                                                <a
                                                    href={`/${item._id}`}
                                                    title=""
                                                    className="p-1 relative inline-flex items-center justify-center px-2 py-2 text-md font-bold text-white transition-all duration-200 bg-gray-900 font-pj rounded-xl focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-gray-900"
                                                    role="button"
                                                >
                                                    বিস্তারিত
                                                </a>
                                            </div>
                                        </div>
                                    </div>
                                    <div className="mt-3 flex w-full justify-center">
                                        <div className="text-2 flex space-x-1 text-sm">
                                            <svg
                                                stroke="currentColor"
                                                fill="currentColor"
                                                strokeWidth="0"
                                                viewBox="0 0 1024 1024"
                                                className="mr-0 flex-shrink-0 lg:mr-1"
                                                height="16"
                                                width="16"
                                                xmlns="http://www.w3.org/2000/svg"
                                            >
                                                <path d="M512 64C264.6 64 64 264.6 64 512s200.6 448 448 448 448-200.6 448-448S759.4 64 512 64zm0 820c-205.4 0-372-166.6-372-372s166.6-372 372-372 372 166.6 372 372-166.6 372-372 372z"></path>
                                                <path d="M464 336a48 48 0 1 0 96 0 48 48 0 1 0-96 0zm72 112h-48c-4.4 0-8 3.6-8 8v272c0 4.4 3.6 8 8 8h48c4.4 0 8-3.6 8-8V456c0-4.4-3.6-8-8-8z"></path>
                                            </svg>
                                            <span className="text-center text-xs md:text-sm">
                                                এনরোলমেন্টের সময় বাংলাদেশি মোবাইল নাম্বার ব্যবহার করুন
                                            </span>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        ))
                    }

                </div>
            </div>
        </div>
    )
}

export default TestCourseItems;
