"use client";

import { useEffect, useState } from "react";
import * as actions from "@/actions";
import Link from "next/link";
import { useSession } from "next-auth/react";
// import avator from "@/asstes/image/avatar.jpg";
import Image from "next/image";
import { usePathname } from "next/navigation";

const HeaderAuth = () => {
  const session = useSession();
  const [isPopupVisible, setIsPopupVisible] = useState(false);

  const handleImageClick = () => {
    setIsPopupVisible(!isPopupVisible);
  };

  const handleSignOut = () => {
    actions.signOut();
  };

  const pathname = usePathname()

  useEffect(() => {
    if (isPopupVisible) {
      setIsPopupVisible(false);
    }
  // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [pathname]);

  return (
    <div className="md:flex items-center justify-end md:flex-1 dark:text-white bg-white dark:bg-gray-900 dark:border-gray-700 z-50 sticky top-0 border-b-2 border-[rgba(248,250,252,.08)] group/auth">
      {session?.data?.user ? (
        <div className="relative">
          <Image
            src={session?.data?.user?.image || '/image/avatar.jpg'}
            alt="Profile"
            className="w-8 h-8 rounded-full cursor-pointer"
            height={0}
            width={0}
            sizes="100vw"
            onClick={() => {
              handleImageClick();
            }}
          />
          
            <div className="absolute right-0 mt-0 w-48 bg-white border rounded-lg shadow-lg invisible group-hover/auth:visible">
              {/* Popup list/dashboard content */}
              <ul className="py-2">
                <li>
                  <Link
                    href="/profile"
                    className="block px-4 py-2 text-gray-800 hover:bg-gray-200"
                  >
                    Dashboard
                  </Link>
                </li>
                <li>
                  <button
                    onClick={handleSignOut}
                    className="block px-4 py-2 text-gray-800 hover:bg-gray-200 w-full text-left"
                  >
                    Sign Out
                  </button>
                </li>
              </ul>
            </div>
          
        </div>
      ) : (
        <Link
          href="/login"
          className="whitespace-nowrap text-base font-medium text-gray-500 hover:text-gray-900 dark:hover:text-white"
        >
          Sign In
        </Link>
      )}
    </div>
  );
};

export default HeaderAuth;
