import React from "react";
import ThemeSwitcher from "../ThemeSwitcher";
import MobileNavbar from "./MobileNavbar";
import HeaderAuth from "./HeaderAuth";
import Image from "next/image";
import Link from "next/link";
import mainLogo from "@/asstes/main-logo.png";

const Navbar = () => {
  return (
    <>
      {/* This example requires Tailwind CSS v2.0+ */}
      <div className="dark:text-white bg-white dark:bg-gray-900 dark:border-gray-700 z-50 sticky top-0 border-b-2 border-[rgba(248,250,252,.08)]">
        <div className="container mx-auto px-4 sm:px-6">
          <div className="flex justify-between items-center py-2 md:justify-start md:space-x-10">
            <div className="flex justify-start lg:w-0 flex-1">
              <Link href="/">
                <span className="sr-only">Workflow</span>
                <Image
                  sizes="100vw"
                  width={0}
                  height={0}
                  className="h-8 w-auto sm:h-10"
                  src={mainLogo}
                  alt="pic"
                />
              </Link>
            </div>
            <div className="flex flex-row gap-4">
              <nav className="hidden md:flex space-x-3">
                <Link
                  href="/"
                  className="text-base font-medium text-gray-500 dark:hover:text-white hover:text-black"
                >
                  হোম
                </Link>
                <div className="relative group/item">
                  <button
                    type="button"
                    className="group bg-white dark:bg-slate-900 rounded-md text-gray-500 inline-flex items-center text-base font-medium hover:text-gray-900 dark:hover:text-white bottom-0"
                  >
                    <span>ক্যাটাগরিসমূহ</span>

                    <svg
                      className={
                        "transform rotate-0 transition ease-out duration-200 ml-2 h-5 w-5 text-gray-400 group-hover:text-gray-500 group-hover/item:rotate-180"
                      }
                      xmlns="http://www.w3.org/2000/svg"
                      viewBox="0 0 20 20"
                      fill="currentColor"
                      aria-hidden="true"
                    >
                      <path
                        fillRule="evenodd"
                        d="M5.293 7.293a1 1 0 011.414 0L10 10.586l3.293-3.293a1 1 0 111.414 1.414l-4 4a1 1 0 01-1.414 0l-4-4a1 1 0 010-1.414z"
                        clipRule="evenodd"
                      />
                    </svg>
                  </button>

                  <div
                    className={
                      "opacity-100 translate-y-0 transition ease-out duration-200 absolute z-10 -ml-4 transform w-screen max-w-md lg:ml-0 lg:left-1/2 lg:-translate-x-1/2 group/edit invisible group-hover/item:visible top-full py-3 px-4 bg-white dark:bg-gray-900"
                    }
                  >
                    <div className="rounded-lg overflow-hidden p-2">
                      <div className="relative grid gap-6 bg-white dark:bg-gray-900 sm:gap-8 ">
                        <Link
                          href="/courses"
                          className="-m-3 p-3 flex items-start rounded-lg hover:bg-gray-50 dark:hover:bg-slate-800"
                        >
                          <svg
                            className="flex-shrink-0 h-6 w-6 text-indigo-600"
                            xmlns="http://www.w3.org/2000/svg"
                            fill="none"
                            viewBox="0 0 24 24"
                            stroke="currentColor"
                            aria-hidden="true"
                          >
                            <path
                              strokeLinecap="round"
                              strokeLinejoin="round"
                              strokeWidth={2}
                              d="M9 19v-6a2 2 0 00-2-2H5a2 2 0 00-2 2v6a2 2 0 002 2h2a2 2 0 002-2zm0 0V9a2 2 0 012-2h2a2 2 0 012 2v10m-6 0a2 2 0 002 2h2a2 2 0 002-2m0 0V5a2 2 0 012-2h2a2 2 0 012 2v14a2 2 0 01-2 2h-2a2 2 0 01-2-2z"
                            />
                          </svg>
                          <div className="ml-4">
                            <p className="text-base font-medium text-gray-900 dark:text-white">
                              কোর্সসমূহ
                            </p>
                          </div>
                        </Link>
                        <Link
                          href="/model-test"
                          className="-m-3 p-3 flex items-start rounded-lg hover:bg-gray-50 dark:hover:bg-slate-800"
                        >
                          <svg
                            className="flex-shrink-0 h-6 w-6 text-indigo-600"
                            xmlns="http://www.w3.org/2000/svg"
                            fill="none"
                            viewBox="0 0 24 24"
                            stroke="currentColor"
                            aria-hidden="true"
                          >
                            <path
                              strokeLinecap="round"
                              strokeLinejoin="round"
                              strokeWidth={2}
                              d="M15 15l-2 5L9 9l11 4-5 2zm0 0l5 5M7.188 2.239l.777 2.897M5.136 7.965l-2.898-.777M13.95 4.05l-2.122 2.122m-5.657 5.656l-2.12 2.122"
                            />
                          </svg>
                          <div className="ml-4">
                            <p className="text-base font-medium text-gray-900 dark:text-white">
                              মডেলটেস্ট সমূহ
                            </p>
                          </div>
                        </Link>
                      </div>
                    </div>
                  </div>
                </div>
                <Link
                  href="/contact"
                  className="text-base font-medium text-gray-500 dark:hover:text-white hover:text-black"
                >
                  যোগাযোগ
                </Link>
              </nav>
              <div className="flex flex-row gap-4">
                <ThemeSwitcher />
              </div>
              <HeaderAuth />
            </div>
          </div>
        </div>
      </div>
      <MobileNavbar />
    </>
  );
};

export default Navbar;
